Class: Aws::Resiliencehubv2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Resiliencehubv2::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-resiliencehubv2/client.rb,
sig/client.rbs
Overview
An API client for Resiliencehubv2. To construct a client, you need to configure a :region and :credentials.
client = Aws::Resiliencehubv2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateAssertionResponseSuccess, _CreateInputSourceResponseSuccess, _CreatePolicyResponseSuccess, _CreateReportResponseSuccess, _CreateServiceFunctionResourcesResponseSuccess, _CreateServiceFunctionResponseSuccess, _CreateServiceResponseSuccess, _CreateSystemResponseSuccess, _CreateTestResponseSuccess, _CreateUserJourneyResponseSuccess, _DeleteAssertionResponseSuccess, _DeleteInputSourceResponseSuccess, _DeletePolicyResponseSuccess, _DeleteServiceFunctionResourcesResponseSuccess, _DeleteServiceFunctionResponseSuccess, _DeleteServiceResponseSuccess, _DeleteSystemResponseSuccess, _DeleteTestResponseSuccess, _DeleteTestSourcesResponseSuccess, _DeleteUserJourneyResponseSuccess, _GetFailureModeFindingResponseSuccess, _GetPolicyResponseSuccess, _GetServiceResponseSuccess, _GetSystemResponseSuccess, _GetTestResponseSuccess, _GetTestRunResponseSuccess, _GetTestTemplateResponseSuccess, _GetUserJourneyResponseSuccess, _ImportAppResponseSuccess, _ImportPolicyResponseSuccess, _ListAssertionsResponseSuccess, _ListDependenciesResponseSuccess, _ListFailureModeAssessmentsResponseSuccess, _ListFailureModeFindingsResponseSuccess, _ListInputSourcesResponseSuccess, _ListPoliciesResponseSuccess, _ListReportsResponseSuccess, _ListResolvedTestRunTargetResourcesResponseSuccess, _ListResourcesResponseSuccess, _ListServiceEventsResponseSuccess, _ListServiceFunctionsResponseSuccess, _ListServiceTopologyEdgesResponseSuccess, _ListServicesResponseSuccess, _ListSystemEventsResponseSuccess, _ListSystemsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTestRunDependenciesResponseSuccess, _ListTestRunEventsResponseSuccess, _ListTestRunSourceEventsResponseSuccess, _ListTestRunSourcesResponseSuccess, _ListTestRunsResponseSuccess, _ListTestSourcesResponseSuccess, _ListTestTemplatesResponseSuccess, _ListTestsResponseSuccess, _ListUserJourneysResponseSuccess, _PutTestSourcesResponseSuccess, _StartFailureModeAssessmentResponseSuccess, _StartTestRunResponseSuccess, _StopTestRunResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAssertionResponseSuccess, _UpdateDependencyResponseSuccess, _UpdateFailureModeFindingResponseSuccess, _UpdatePolicyResponseSuccess, _UpdateServiceFunctionResponseSuccess, _UpdateServiceResponseSuccess, _UpdateSystemResponseSuccess, _UpdateTestResponseSuccess, _UpdateUserJourneyResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_assertion(params = {}) ⇒ Types::CreateAssertionResponse
Creates a resilience assertion for a service.
-
#create_input_source(params = {}) ⇒ Types::CreateInputSourceResponse
Creates an input source for a service.
-
#create_policy(params = {}) ⇒ Types::CreatePolicyResponse
Creates a resilience policy that defines availability and disaster recovery requirements.
-
#create_report(params = {}) ⇒ Types::CreateReportResponse
On-demand report creation.
-
#create_service(params = {}) ⇒ Types::CreateServiceResponse
Creates a service.
-
#create_service_function(params = {}) ⇒ Types::CreateServiceFunctionResponse
Creates a service function within a service.
-
#create_service_function_resources(params = {}) ⇒ Types::CreateServiceFunctionResourcesResponse
Associates resources with a service function.
-
#create_system(params = {}) ⇒ Types::CreateSystemResponse
Creates a system that represents a logical grouping of services.
-
#create_test(params = {}) ⇒ Types::CreateTestResponse
Creates a test for a service by configuring a test template.
-
#create_user_journey(params = {}) ⇒ Types::CreateUserJourneyResponse
Creates a user journey within a system.
-
#delete_assertion(params = {}) ⇒ Types::DeleteAssertionResponse
Deletes a resilience assertion from a service.
-
#delete_input_source(params = {}) ⇒ Types::DeleteInputSourceResponse
Deletes an input source.
-
#delete_policy(params = {}) ⇒ Types::DeletePolicyResponse
Deletes a resilience policy.
-
#delete_service(params = {}) ⇒ Types::DeleteServiceResponse
Deletes a service.
-
#delete_service_function(params = {}) ⇒ Types::DeleteServiceFunctionResponse
Deletes a service function.
-
#delete_service_function_resources(params = {}) ⇒ Types::DeleteServiceFunctionResourcesResponse
Removes resources from a service function.
-
#delete_system(params = {}) ⇒ Types::DeleteSystemResponse
Deletes a system.
-
#delete_test(params = {}) ⇒ Types::DeleteTestResponse
Deletes a test.
-
#delete_test_sources(params = {}) ⇒ Struct
Removes monitoring sources from a test.
-
#delete_user_journey(params = {}) ⇒ Types::DeleteUserJourneyResponse
Deletes a user journey.
-
#get_failure_mode_finding(params = {}) ⇒ Types::GetFailureModeFindingResponse
Retrieves a finding by findingId.
-
#get_policy(params = {}) ⇒ Types::GetPolicyResponse
Retrieves a resilience policy by ARN.
-
#get_service(params = {}) ⇒ Types::GetServiceResponse
Retrieves a service by ARN.
-
#get_system(params = {}) ⇒ Types::GetSystemResponse
Retrieves a system by ARN.
-
#get_test(params = {}) ⇒ Types::GetTestResponse
Retrieves a test by ID.
-
#get_test_run(params = {}) ⇒ Types::GetTestRunResponse
Retrieves a test run by ID, including its status, results, and the configuration snapshotted when the run started.
-
#get_test_template(params = {}) ⇒ Types::GetTestTemplateResponse
Retrieves a resilience test template by ARN, including the parameters it accepts and the fault actions it runs.
-
#get_user_journey(params = {}) ⇒ Types::GetUserJourneyResponse
Retrieves a user journey.
-
#import_app(params = {}) ⇒ Types::ImportAppResponse
Imports a V1 app into the V2 resource model, creating a service with the same name.
-
#import_policy(params = {}) ⇒ Types::ImportPolicyResponse
Imports a V1 policy into V2, mapping RTO/RPO values from V1 scenarios.
-
#list_assertions(params = {}) ⇒ Types::ListAssertionsResponse
Lists resilience assertions for a service.
-
#list_dependencies(params = {}) ⇒ Types::ListDependenciesResponse
Lists dependencies discovered for services.
-
#list_failure_mode_assessments(params = {}) ⇒ Types::ListFailureModeAssessmentsResponse
Lists failure mode assessments.
-
#list_failure_mode_findings(params = {}) ⇒ Types::ListFailureModeFindingsResponse
List findings.
-
#list_input_sources(params = {}) ⇒ Types::ListInputSourcesResponse
Lists input sources for a service.
-
#list_policies(params = {}) ⇒ Types::ListPoliciesResponse
Lists resilience policies.
-
#list_reports(params = {}) ⇒ Types::ListReportsResponse
List reports for a service, or all reports owned by the account if serviceArn is not provided.
-
#list_resolved_test_run_target_resources(params = {}) ⇒ Types::ListResolvedTestRunTargetResourcesResponse
Lists the AWS resources that AWS Fault Injection Service (AWS FIS) resolved as targets for a test run.
-
#list_resources(params = {}) ⇒ Types::ListResourcesResponse
List resources.
-
#list_service_events(params = {}) ⇒ Types::ListServiceEventsResponse
Lists events for a service.
-
#list_service_functions(params = {}) ⇒ Types::ListServiceFunctionsResponse
Lists service functions for a service.
-
#list_service_topology_edges(params = {}) ⇒ Types::ListServiceTopologyEdgesResponse
Lists topology edges for a service.
-
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists services.
-
#list_system_events(params = {}) ⇒ Types::ListSystemEventsResponse
Lists events for a system.
-
#list_systems(params = {}) ⇒ Types::ListSystemsResponse
Lists systems.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a resource.
-
#list_test_run_dependencies(params = {}) ⇒ Types::ListTestRunDependenciesResponse
Lists the dependencies that a test run blocked.
-
#list_test_run_events(params = {}) ⇒ Types::ListTestRunEventsResponse
Lists the events in a test run's timeline.
-
#list_test_run_source_events(params = {}) ⇒ Types::ListTestRunSourceEventsResponse
Lists the state-change events observed for a test run monitoring source.
-
#list_test_run_sources(params = {}) ⇒ Types::ListTestRunSourcesResponse
Lists the monitoring source snapshots captured for a test run, optionally filtered by type.
-
#list_test_runs(params = {}) ⇒ Types::ListTestRunsResponse
Lists the runs of a test, or all test runs for a service.
-
#list_test_sources(params = {}) ⇒ Types::ListTestSourcesResponse
Lists the monitoring sources attached to a test, optionally filtered by type.
-
#list_test_templates(params = {}) ⇒ Types::ListTestTemplatesResponse
Lists the available resilience test templates.
-
#list_tests(params = {}) ⇒ Types::ListTestsResponse
Lists the tests configured for a service.
-
#list_user_journeys(params = {}) ⇒ Types::ListUserJourneysResponse
Lists user journeys for a system.
-
#put_test_sources(params = {}) ⇒ Struct
Adds or updates the monitoring sources on a test.
-
#start_failure_mode_assessment(params = {}) ⇒ Types::StartFailureModeAssessmentResponse
Starts a failure mode assessment.
-
#start_test_run(params = {}) ⇒ Types::StartTestRunResponse
Starts a run of a test.
-
#stop_test_run(params = {}) ⇒ Types::StopTestRunResponse
Stops an in-progress test run.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_assertion(params = {}) ⇒ Types::UpdateAssertionResponse
Updates a resilience assertion.
-
#update_dependency(params = {}) ⇒ Types::UpdateDependencyResponse
Updates a dependency classification.
-
#update_failure_mode_finding(params = {}) ⇒ Types::UpdateFailureModeFindingResponse
Updates an existing finding.
-
#update_policy(params = {}) ⇒ Types::UpdatePolicyResponse
Updates an existing resilience policy.
-
#update_service(params = {}) ⇒ Types::UpdateServiceResponse
Updates an existing service.
-
#update_service_function(params = {}) ⇒ Types::UpdateServiceFunctionResponse
Updates a service function.
-
#update_system(params = {}) ⇒ Types::UpdateSystemResponse
Updates an existing system.
-
#update_test(params = {}) ⇒ Types::UpdateTestResponse
Updates the configuration of an existing test.
-
#update_user_journey(params = {}) ⇒ Types::UpdateUserJourneyResponse
Updates an existing user journey.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-resiliencehubv2/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4613 4614 4615 |
# File 'lib/aws-sdk-resiliencehubv2/client.rb', line 4613 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4616 4617 4618 |
# File 'lib/aws-sdk-resiliencehubv2/client.rb', line 4616 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 |
# File 'lib/aws-sdk-resiliencehubv2/client.rb', line 4467 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Resiliencehubv2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-resiliencehubv2' context[:gem_version] = '1.6.0' Seahorse::Client::Request.new(handlers, context) end |
#create_assertion(params = {}) ⇒ Types::CreateAssertionResponse
Creates a resilience assertion for a service.
86 |
# File 'sig/client.rbs', line 86
def create_assertion: (
|
#create_input_source(params = {}) ⇒ Types::CreateInputSourceResponse
Creates an input source for a service.
99 |
# File 'sig/client.rbs', line 99
def create_input_source: (
|
#create_policy(params = {}) ⇒ Types::CreatePolicyResponse
Creates a resilience policy that defines availability and disaster recovery requirements.
135 |
# File 'sig/client.rbs', line 135
def create_policy: (
|
#create_report(params = {}) ⇒ Types::CreateReportResponse
On-demand report creation. Idempotent — duplicate requests with same clientToken return existing result.
165 |
# File 'sig/client.rbs', line 165
def create_report: (
|
#create_service(params = {}) ⇒ Types::CreateServiceResponse
Creates a service.
177 |
# File 'sig/client.rbs', line 177
def create_service: (
|
#create_service_function(params = {}) ⇒ Types::CreateServiceFunctionResponse
Creates a service function within a service.
211 |
# File 'sig/client.rbs', line 211
def create_service_function: (
|
#create_service_function_resources(params = {}) ⇒ Types::CreateServiceFunctionResourcesResponse
Associates resources with a service function.
227 |
# File 'sig/client.rbs', line 227
def create_service_function_resources: (
|
#create_system(params = {}) ⇒ Types::CreateSystemResponse
Creates a system that represents a logical grouping of services.
239 |
# File 'sig/client.rbs', line 239
def create_system: (
|
#create_test(params = {}) ⇒ Types::CreateTestResponse
Creates a test for a service by configuring a test template. Each service has one test per template.
254 |
# File 'sig/client.rbs', line 254
def create_test: (
|
#create_user_journey(params = {}) ⇒ Types::CreateUserJourneyResponse
Creates a user journey within a system.
278 |
# File 'sig/client.rbs', line 278
def create_user_journey: (
|
#delete_assertion(params = {}) ⇒ Types::DeleteAssertionResponse
Deletes a resilience assertion from a service.
292 |
# File 'sig/client.rbs', line 292
def delete_assertion: (
|
#delete_input_source(params = {}) ⇒ Types::DeleteInputSourceResponse
Deletes an input source.
304 |
# File 'sig/client.rbs', line 304
def delete_input_source: (
|
#delete_policy(params = {}) ⇒ Types::DeletePolicyResponse
Deletes a resilience policy.
315 |
# File 'sig/client.rbs', line 315
def delete_policy: (
|
#delete_service(params = {}) ⇒ Types::DeleteServiceResponse
Deletes a service.
325 |
# File 'sig/client.rbs', line 325
def delete_service: (
|
#delete_service_function(params = {}) ⇒ Types::DeleteServiceFunctionResponse
Deletes a service function.
335 |
# File 'sig/client.rbs', line 335
def delete_service_function: (
|
#delete_service_function_resources(params = {}) ⇒ Types::DeleteServiceFunctionResourcesResponse
Removes resources from a service function.
348 |
# File 'sig/client.rbs', line 348
def delete_service_function_resources: (
|
#delete_system(params = {}) ⇒ Types::DeleteSystemResponse
Deletes a system.
360 |
# File 'sig/client.rbs', line 360
def delete_system: (
|
#delete_test(params = {}) ⇒ Types::DeleteTestResponse
Deletes a test.
370 |
# File 'sig/client.rbs', line 370
def delete_test: (
|
#delete_test_sources(params = {}) ⇒ Struct
Removes monitoring sources from a test. The operation is transactional and idempotent — removing a source that is not attached is a no-op.
380 |
# File 'sig/client.rbs', line 380
def delete_test_sources: (
|
#delete_user_journey(params = {}) ⇒ Types::DeleteUserJourneyResponse
Deletes a user journey.
394 |
# File 'sig/client.rbs', line 394
def delete_user_journey: (
|
#get_failure_mode_finding(params = {}) ⇒ Types::GetFailureModeFindingResponse
Retrieves a finding by findingId.
405 |
# File 'sig/client.rbs', line 405
def get_failure_mode_finding: (
|
#get_policy(params = {}) ⇒ Types::GetPolicyResponse
Retrieves a resilience policy by ARN.
416 |
# File 'sig/client.rbs', line 416
def get_policy: (
|
#get_service(params = {}) ⇒ Types::GetServiceResponse
Retrieves a service by ARN.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* service_assessment_completed
* service_resource_discovery_completed
426 |
# File 'sig/client.rbs', line 426
def get_service: (
|
#get_system(params = {}) ⇒ Types::GetSystemResponse
Retrieves a system by ARN.
436 |
# File 'sig/client.rbs', line 436
def get_system: (
|
#get_test(params = {}) ⇒ Types::GetTestResponse
Retrieves a test by ID.
446 |
# File 'sig/client.rbs', line 446
def get_test: (
|
#get_test_run(params = {}) ⇒ Types::GetTestRunResponse
Retrieves a test run by ID, including its status, results, and the configuration snapshotted when the run started.
457 |
# File 'sig/client.rbs', line 457
def get_test_run: (
|
#get_test_template(params = {}) ⇒ Types::GetTestTemplateResponse
Retrieves a resilience test template by ARN, including the parameters it accepts and the fault actions it runs.
468 |
# File 'sig/client.rbs', line 468
def get_test_template: (
|
#get_user_journey(params = {}) ⇒ Types::GetUserJourneyResponse
Retrieves a user journey.
478 |
# File 'sig/client.rbs', line 478
def get_user_journey: (
|
#import_app(params = {}) ⇒ Types::ImportAppResponse
Imports a V1 app into the V2 resource model, creating a service with the same name.
489 |
# File 'sig/client.rbs', line 489
def import_app: (
|
#import_policy(params = {}) ⇒ Types::ImportPolicyResponse
Imports a V1 policy into V2, mapping RTO/RPO values from V1 scenarios.
511 |
# File 'sig/client.rbs', line 511
def import_policy: (
|
#list_assertions(params = {}) ⇒ Types::ListAssertionsResponse
Lists resilience assertions for a service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
530 |
# File 'sig/client.rbs', line 530
def list_assertions: (
|
#list_dependencies(params = {}) ⇒ Types::ListDependenciesResponse
Lists dependencies discovered for services.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
544 |
# File 'sig/client.rbs', line 544
def list_dependencies: (
|
#list_failure_mode_assessments(params = {}) ⇒ Types::ListFailureModeAssessmentsResponse
Lists failure mode assessments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* failure_mode_assessment_success
560 |
# File 'sig/client.rbs', line 560
def list_failure_mode_assessments: (
|
#list_failure_mode_findings(params = {}) ⇒ Types::ListFailureModeFindingsResponse
List findings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
578 |
# File 'sig/client.rbs', line 578
def list_failure_mode_findings: (
|
#list_input_sources(params = {}) ⇒ Types::ListInputSourcesResponse
Lists input sources for a service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
594 |
# File 'sig/client.rbs', line 594
def list_input_sources: (
|
#list_policies(params = {}) ⇒ Types::ListPoliciesResponse
Lists resilience policies.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
608 |
# File 'sig/client.rbs', line 608
def list_policies: (
|
#list_reports(params = {}) ⇒ Types::ListReportsResponse
List reports for a service, or all reports owned by the account if serviceArn is not provided.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* report_succeeded
620 |
# File 'sig/client.rbs', line 620
def list_reports: (
|
#list_resolved_test_run_target_resources(params = {}) ⇒ Types::ListResolvedTestRunTargetResourcesResponse
Lists the AWS resources that AWS Fault Injection Service (AWS FIS) resolved as targets for a test run.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
635 |
# File 'sig/client.rbs', line 635
def list_resolved_test_run_target_resources: (
|
#list_resources(params = {}) ⇒ Types::ListResourcesResponse
List resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
650 |
# File 'sig/client.rbs', line 650
def list_resources: (
|
#list_service_events(params = {}) ⇒ Types::ListServiceEventsResponse
Lists events for a service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
667 |
# File 'sig/client.rbs', line 667
def list_service_events: (
|
#list_service_functions(params = {}) ⇒ Types::ListServiceFunctionsResponse
Lists service functions for a service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
683 |
# File 'sig/client.rbs', line 683
def list_service_functions: (
|
#list_service_topology_edges(params = {}) ⇒ Types::ListServiceTopologyEdgesResponse
Lists topology edges for a service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
696 |
# File 'sig/client.rbs', line 696
def list_service_topology_edges: (
|
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists services.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
709 |
# File 'sig/client.rbs', line 709
def list_services: (
|
#list_system_events(params = {}) ⇒ Types::ListSystemEventsResponse
Lists events for a system.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
727 |
# File 'sig/client.rbs', line 727
def list_system_events: (
|
#list_systems(params = {}) ⇒ Types::ListSystemsResponse
Lists systems.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
743 |
# File 'sig/client.rbs', line 743
def list_systems: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a resource.
755 |
# File 'sig/client.rbs', line 755
def list_tags_for_resource: (
|
#list_test_run_dependencies(params = {}) ⇒ Types::ListTestRunDependenciesResponse
Lists the dependencies that a test run blocked. Each dependency reflects the discovered classification captured when the run started, so results do not change if a dependency is reclassified after the run.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
766 |
# File 'sig/client.rbs', line 766
def list_test_run_dependencies: (
|
#list_test_run_events(params = {}) ⇒ Types::ListTestRunEventsResponse
Lists the events in a test run's timeline.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
780 |
# File 'sig/client.rbs', line 780
def list_test_run_events: (
|
#list_test_run_source_events(params = {}) ⇒ Types::ListTestRunSourceEventsResponse
Lists the state-change events observed for a test run monitoring source. Events are returned for one source per call, in chronological order.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
796 |
# File 'sig/client.rbs', line 796
def list_test_run_source_events: (
|
#list_test_run_sources(params = {}) ⇒ Types::ListTestRunSourcesResponse
Lists the monitoring source snapshots captured for a test run, optionally filtered by type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
811 |
# File 'sig/client.rbs', line 811
def list_test_run_sources: (
|
#list_test_runs(params = {}) ⇒ Types::ListTestRunsResponse
Lists the runs of a test, or all test runs for a service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
826 |
# File 'sig/client.rbs', line 826
def list_test_runs: (
|
#list_test_sources(params = {}) ⇒ Types::ListTestSourcesResponse
Lists the monitoring sources attached to a test, optionally filtered by type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
840 |
# File 'sig/client.rbs', line 840
def list_test_sources: (
|
#list_test_templates(params = {}) ⇒ Types::ListTestTemplatesResponse
Lists the available resilience test templates. A test template is a pre-configured, AWS recommended test that defines which resilience capability to validate.
854 |
# File 'sig/client.rbs', line 854
def list_test_templates: (
|
#list_tests(params = {}) ⇒ Types::ListTestsResponse
Lists the tests configured for a service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
864 |
# File 'sig/client.rbs', line 864
def list_tests: (
|
#list_user_journeys(params = {}) ⇒ Types::ListUserJourneysResponse
Lists user journeys for a system.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
877 |
# File 'sig/client.rbs', line 877
def list_user_journeys: (
|
#put_test_sources(params = {}) ⇒ Struct
Adds or updates the monitoring sources on a test. The operation is transactional — either every source is written or the call fails and nothing is written.
888 |
# File 'sig/client.rbs', line 888
def put_test_sources: (
|
#start_failure_mode_assessment(params = {}) ⇒ Types::StartFailureModeAssessmentResponse
Starts a failure mode assessment.
905 |
# File 'sig/client.rbs', line 905
def start_failure_mode_assessment: (
|
#start_test_run(params = {}) ⇒ Types::StartTestRunResponse
Starts a run of a test. Each run scopes to the current resources in the service and produces a pass or fail outcome.
918 |
# File 'sig/client.rbs', line 918
def start_test_run: (
|
#stop_test_run(params = {}) ⇒ Types::StopTestRunResponse
Stops an in-progress test run.
930 |
# File 'sig/client.rbs', line 930
def stop_test_run: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
940 |
# File 'sig/client.rbs', line 940
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
950 |
# File 'sig/client.rbs', line 950
def untag_resource: (
|
#update_assertion(params = {}) ⇒ Types::UpdateAssertionResponse
Updates a resilience assertion.
961 |
# File 'sig/client.rbs', line 961
def update_assertion: (
|
#update_dependency(params = {}) ⇒ Types::UpdateDependencyResponse
Updates a dependency classification.
979 |
# File 'sig/client.rbs', line 979
def update_dependency: (
|
#update_failure_mode_finding(params = {}) ⇒ Types::UpdateFailureModeFindingResponse
Updates an existing finding.
992 |
# File 'sig/client.rbs', line 992
def update_failure_mode_finding: (
|
#update_policy(params = {}) ⇒ Types::UpdatePolicyResponse
Updates an existing resilience policy.
1005 |
# File 'sig/client.rbs', line 1005
def update_policy: (
|
#update_service(params = {}) ⇒ Types::UpdateServiceResponse
Updates an existing service.
1032 |
# File 'sig/client.rbs', line 1032
def update_service: (
|
#update_service_function(params = {}) ⇒ Types::UpdateServiceFunctionResponse
Updates a service function.
1063 |
# File 'sig/client.rbs', line 1063
def update_service_function: (
|
#update_system(params = {}) ⇒ Types::UpdateSystemResponse
Updates an existing system.
1077 |
# File 'sig/client.rbs', line 1077
def update_system: (
|
#update_test(params = {}) ⇒ Types::UpdateTestResponse
Updates the configuration of an existing test.
1089 |
# File 'sig/client.rbs', line 1089
def update_test: (
|
#update_user_journey(params = {}) ⇒ Types::UpdateUserJourneyResponse
Updates an existing user journey.
1113 |
# File 'sig/client.rbs', line 1113
def update_user_journey: (
|
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
Basic Usage
A waiter will call an API operation until:
- It is successful
- It enters a terminal state
- It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
Valid Waiters
The following table lists the valid waiter names, the operations they call,
and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts |
|---|---|---|---|
| failure_mode_assessment_success | #list_failure_mode_assessments | 30 | 5 |
| report_succeeded | #list_reports | 30 | 5 |
| service_assessment_completed | #get_service | 30 | 5 |
| service_resource_discovery_completed | #get_service | 30 | 5 |
1123 |
# File 'sig/client.rbs', line 1123
def wait_until: (:failure_mode_assessment_success waiter_name,
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4584 4585 4586 |
# File 'lib/aws-sdk-resiliencehubv2/client.rb', line 4584 def waiter_names waiters.keys end |