Class: Aws::Resiliencehubv2::Types::Achievability
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::Achievability
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Describes the achievability status of a service's resilience targets based on the most recent assessment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_slo ⇒ String
The achievability status of the availability SLO target for the service.
-
#data_recovery_time_between_backups ⇒ String
The achievability status of the data recovery time between backups for the service.
-
#multi_az_rto_rpo ⇒ String
The achievability status of the multi-AZ RTO and RPO targets for the service.
-
#multi_region_rto_rpo ⇒ String
The achievability status of the multi-Region RTO and RPO targets for the service.
Instance Attribute Details
#availability_slo ⇒ String
The achievability status of the availability SLO target for the service.
51 52 53 54 55 56 57 58 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 51 class Achievability < Struct.new( :availability_slo, :multi_az_rto_rpo, :multi_region_rto_rpo, :data_recovery_time_between_backups) SENSITIVE = [] include Aws::Structure end |
#data_recovery_time_between_backups ⇒ String
The achievability status of the data recovery time between backups for the service.
51 52 53 54 55 56 57 58 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 51 class Achievability < Struct.new( :availability_slo, :multi_az_rto_rpo, :multi_region_rto_rpo, :data_recovery_time_between_backups) SENSITIVE = [] include Aws::Structure end |
#multi_az_rto_rpo ⇒ String
The achievability status of the multi-AZ RTO and RPO targets for the service.
51 52 53 54 55 56 57 58 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 51 class Achievability < Struct.new( :availability_slo, :multi_az_rto_rpo, :multi_region_rto_rpo, :data_recovery_time_between_backups) SENSITIVE = [] include Aws::Structure end |
#multi_region_rto_rpo ⇒ String
The achievability status of the multi-Region RTO and RPO targets for the service.
51 52 53 54 55 56 57 58 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 51 class Achievability < Struct.new( :availability_slo, :multi_az_rto_rpo, :multi_region_rto_rpo, :data_recovery_time_between_backups) SENSITIVE = [] include Aws::Structure end |