Class: Aws::Resiliencehubv2::Types::AlarmStateChangeDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Details about a CloudWatch alarm state change observed during a test run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#previous_stateString

The state the alarm transitioned from. Absent on the initial event, which records the alarm's state when collection began.

Returns:

  • (String)


79
80
81
82
83
84
85
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 79

class AlarmStateChangeDetail < Struct.new(
  :state,
  :previous_state,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

A human-readable explanation of the state change, as reported by CloudWatch.

Returns:

  • (String)


79
80
81
82
83
84
85
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 79

class AlarmStateChangeDetail < Struct.new(
  :state,
  :previous_state,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state the alarm transitioned to.

Returns:

  • (String)


79
80
81
82
83
84
85
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 79

class AlarmStateChangeDetail < Struct.new(
  :state,
  :previous_state,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end