Class: Aws::Resiliencehubv2::Types::Assertion
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::Assertion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Represents a resilience assertion for a service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assertion_id ⇒ String
The unique identifier of the assertion.
-
#created_at ⇒ Time
The timestamp when the assertion was created.
-
#service_arn ⇒ String
ARN identifier.
-
#source ⇒ String
The source of the assertion, indicating whether it was AI-generated or created by a user.
-
#text ⇒ String
The text content of the assertion.
-
#updated_at ⇒ Time
The timestamp when the assertion was last updated.
Instance Attribute Details
#assertion_id ⇒ String
The unique identifier of the assertion.
89 90 91 92 93 94 95 96 97 98 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 89 class Assertion < Struct.new( :service_arn, :assertion_id, :text, :source, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the assertion was created.
89 90 91 92 93 94 95 96 97 98 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 89 class Assertion < Struct.new( :service_arn, :assertion_id, :text, :source, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
ARN identifier.
89 90 91 92 93 94 95 96 97 98 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 89 class Assertion < Struct.new( :service_arn, :assertion_id, :text, :source, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The source of the assertion, indicating whether it was AI-generated or created by a user.
89 90 91 92 93 94 95 96 97 98 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 89 class Assertion < Struct.new( :service_arn, :assertion_id, :text, :source, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |