Class: Aws::Resiliencehubv2::Types::AssociatedSystem
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::AssociatedSystem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Represents a system associated with a service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#system_arn ⇒ String
ARN identifier.
-
#system_name ⇒ String
Resource name (used in ARN — no spaces allowed).
-
#user_journey_ids ⇒ Array<String>
The list of user journey identifiers that associate this system with the service.
Instance Attribute Details
#system_arn ⇒ String
ARN identifier.
256 257 258 259 260 261 262 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 256 class AssociatedSystem < Struct.new( :system_arn, :system_name, :user_journey_ids) SENSITIVE = [] include Aws::Structure end |
#system_name ⇒ String
Resource name (used in ARN — no spaces allowed).
256 257 258 259 260 261 262 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 256 class AssociatedSystem < Struct.new( :system_arn, :system_name, :user_journey_ids) SENSITIVE = [] include Aws::Structure end |
#user_journey_ids ⇒ Array<String>
The list of user journey identifiers that associate this system with the service.
256 257 258 259 260 261 262 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 256 class AssociatedSystem < Struct.new( :system_arn, :system_name, :user_journey_ids) SENSITIVE = [] include Aws::Structure end |