Class: Aws::Resiliencehubv2::Types::AvailabilitySlo
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::AvailabilitySlo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Defines the availability service level objective (SLO) for a resilience policy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#target ⇒ Float
The target availability percentage, expressed as a value between 0 and 100.
Instance Attribute Details
#target ⇒ Float
The target availability percentage, expressed as a value between 0 and 100.
307 308 309 310 311 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 307 class AvailabilitySlo < Struct.new( :target) SENSITIVE = [] include Aws::Structure end |