Class: Aws::Resiliencehubv2::Types::CreateInputSourceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::CreateInputSourceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_source_id ⇒ String
The unique identifier assigned to the created input source.
-
#service_arn ⇒ String
ARN identifier.
Instance Attribute Details
#input_source_id ⇒ String
The unique identifier assigned to the created input source.
366 367 368 369 370 371 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 366 class CreateInputSourceResponse < Struct.new( :service_arn, :input_source_id) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
ARN identifier.
366 367 368 369 370 371 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 366 class CreateInputSourceResponse < Struct.new( :service_arn, :input_source_id) SENSITIVE = [] include Aws::Structure end |