Class: Aws::Resiliencehubv2::Types::CreateServiceFunctionResourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::CreateServiceFunctionResourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resources ⇒ Array<String>
The list of resources to associate with the service function.
-
#service_arn ⇒ String
ARN identifier.
-
#service_function_id ⇒ String
The identifier of the service function to associate resources with.
Instance Attribute Details
#resources ⇒ Array<String>
The list of resources to associate with the service function.
534 535 536 537 538 539 540 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 534 class CreateServiceFunctionResourcesRequest < Struct.new( :service_arn, :service_function_id, :resources) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
ARN identifier.
534 535 536 537 538 539 540 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 534 class CreateServiceFunctionResourcesRequest < Struct.new( :service_arn, :service_function_id, :resources) SENSITIVE = [] include Aws::Structure end |
#service_function_id ⇒ String
The identifier of the service function to associate resources with.
534 535 536 537 538 539 540 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 534 class CreateServiceFunctionResourcesRequest < Struct.new( :service_arn, :service_function_id, :resources) SENSITIVE = [] include Aws::Structure end |