Class: Aws::Resiliencehubv2::Types::CreateTestRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#logging_configurationTypes::LoggingConfiguration

The logging configuration for the test.



734
735
736
737
738
739
740
741
742
743
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 734

class CreateTestRequest < Struct.new(
  :service_arn,
  :test_template_arn,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,Array<String>>

The parameter values for the test.

Returns:

  • (Hash<String,Array<String>>)


734
735
736
737
738
739
740
741
742
743
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 734

class CreateTestRequest < Struct.new(
  :service_arn,
  :test_template_arn,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#role_nameString

The name of the IAM execution role to use when running the test.

Returns:

  • (String)


734
735
736
737
738
739
740
741
742
743
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 734

class CreateTestRequest < Struct.new(
  :service_arn,
  :test_template_arn,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnString

The ARN of the service to create the test for.

Returns:

  • (String)


734
735
736
737
738
739
740
741
742
743
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 734

class CreateTestRequest < Struct.new(
  :service_arn,
  :test_template_arn,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#stop_conditionsArray<Types::StopCondition>

The stop conditions for the test.

Returns:



734
735
736
737
738
739
740
741
742
743
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 734

class CreateTestRequest < Struct.new(
  :service_arn,
  :test_template_arn,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#test_template_arnString

The ARN of the test template to configure.

Returns:

  • (String)


734
735
736
737
738
739
740
741
742
743
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 734

class CreateTestRequest < Struct.new(
  :service_arn,
  :test_template_arn,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end