Class: Aws::Resiliencehubv2::Types::DeleteServiceFunctionResourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::DeleteServiceFunctionResourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resources ⇒ Array<String>
The list of resources to remove from the service function.
-
#service_arn ⇒ String
ARN identifier.
-
#service_function_id ⇒ String
The identifier of the service function to remove resources from.
Instance Attribute Details
#resources ⇒ Array<String>
The list of resources to remove from the service function.
901 902 903 904 905 906 907 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 901 class DeleteServiceFunctionResourcesRequest < Struct.new( :service_arn, :service_function_id, :resources) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
ARN identifier.
901 902 903 904 905 906 907 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 901 class DeleteServiceFunctionResourcesRequest < Struct.new( :service_arn, :service_function_id, :resources) SENSITIVE = [] include Aws::Structure end |
#service_function_id ⇒ String
The identifier of the service function to remove resources from.
901 902 903 904 905 906 907 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 901 class DeleteServiceFunctionResourcesRequest < Struct.new( :service_arn, :service_function_id, :resources) SENSITIVE = [] include Aws::Structure end |