Class: Aws::Resiliencehubv2::Types::DeleteTestSourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::DeleteTestSourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service_arn ⇒ String
The ARN of the service the test belongs to.
-
#test_id ⇒ String
The identifier of the test to remove sources from.
-
#test_sources ⇒ Array<Types::TestSourceInput>
The monitoring sources to remove.
Instance Attribute Details
#service_arn ⇒ String
The ARN of the service the test belongs to.
1089 1090 1091 1092 1093 1094 1095 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1089 class DeleteTestSourcesRequest < Struct.new( :test_id, :service_arn, :test_sources) SENSITIVE = [] include Aws::Structure end |
#test_id ⇒ String
The identifier of the test to remove sources from.
1089 1090 1091 1092 1093 1094 1095 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1089 class DeleteTestSourcesRequest < Struct.new( :test_id, :service_arn, :test_sources) SENSITIVE = [] include Aws::Structure end |
#test_sources ⇒ Array<Types::TestSourceInput>
The monitoring sources to remove.
1089 1090 1091 1092 1093 1094 1095 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1089 class DeleteTestSourcesRequest < Struct.new( :test_id, :service_arn, :test_sources) SENSITIVE = [] include Aws::Structure end |