Class: Aws::Resiliencehubv2::Types::EksLabelSelectorRequirement
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::EksLabelSelectorRequirement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
A single label requirement in a label selector, expressed as a key, an operator, and an optional list of values.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ String
The label key that the requirement applies to.
-
#operator ⇒ String
The operator that relates the label key to the values.
-
#values ⇒ Array<String>
The label values to compare against.
Instance Attribute Details
#key ⇒ String
The label key that the requirement applies to.
1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1391 class EksLabelSelectorRequirement < Struct.new( :key, :operator, :values) SENSITIVE = [] include Aws::Structure end |
#operator ⇒ String
The operator that relates the label key to the values.
1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1391 class EksLabelSelectorRequirement < Struct.new( :key, :operator, :values) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<String>
The label values to compare against. Specify values when the operator is IN or NOT_IN. Leave this empty when the operator is EXISTS or DOES_NOT_EXIST.
1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1391 class EksLabelSelectorRequirement < Struct.new( :key, :operator, :values) SENSITIVE = [] include Aws::Structure end |