Class: Aws::Resiliencehubv2::Types::EksSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Defines an Amazon EKS cluster and its namespaces as an input source for resource discovery.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_arnString

ARN identifier.

Returns:

  • (String)


1418
1419
1420
1421
1422
1423
1424
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1418

class EksSource < Struct.new(
  :cluster_arn,
  :namespaces,
  :label_selector)
  SENSITIVE = []
  include Aws::Structure
end

#label_selectorTypes::EksLabelSelector

Filters discovery to the Kubernetes objects whose labels match the selector. When omitted, all supported objects in the specified namespaces are discovered.



1418
1419
1420
1421
1422
1423
1424
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1418

class EksSource < Struct.new(
  :cluster_arn,
  :namespaces,
  :label_selector)
  SENSITIVE = []
  include Aws::Structure
end

#namespacesArray<String>

The list of Kubernetes namespaces within the EKS cluster.

Returns:

  • (Array<String>)


1418
1419
1420
1421
1422
1423
1424
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1418

class EksSource < Struct.new(
  :cluster_arn,
  :namespaces,
  :label_selector)
  SENSITIVE = []
  include Aws::Structure
end