Class: Aws::Resiliencehubv2::Types::GetTestRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::GetTestRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service_arn ⇒ String
The ARN of the service the test run belongs to.
-
#test_run_id ⇒ String
The identifier of the test run to retrieve.
Instance Attribute Details
#service_arn ⇒ String
The ARN of the service the test run belongs to.
1767 1768 1769 1770 1771 1772 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1767 class GetTestRunRequest < Struct.new( :test_run_id, :service_arn) SENSITIVE = [] include Aws::Structure end |
#test_run_id ⇒ String
The identifier of the test run to retrieve.
1767 1768 1769 1770 1771 1772 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1767 class GetTestRunRequest < Struct.new( :test_run_id, :service_arn) SENSITIVE = [] include Aws::Structure end |