Class: Aws::Resiliencehubv2::Types::InputSourceSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Contains summary information about an input source for a service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cfn_stack_arnString

ARN identifier.

Returns:

  • (String)


1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716

class InputSourceSummary < Struct.new(
  :input_source_id,
  :type,
  :resource_tags,
  :cfn_stack_arn,
  :tf_state_file_url,
  :eks,
  :design_file_s3_url,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp when the input source was created.

Returns:

  • (Time)


1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716

class InputSourceSummary < Struct.new(
  :input_source_id,
  :type,
  :resource_tags,
  :cfn_stack_arn,
  :tf_state_file_url,
  :eks,
  :design_file_s3_url,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#design_file_s3_urlString

S3 URL — virtual hosted-style or s3:// URI.

Returns:

  • (String)


1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716

class InputSourceSummary < Struct.new(
  :input_source_id,
  :type,
  :resource_tags,
  :cfn_stack_arn,
  :tf_state_file_url,
  :eks,
  :design_file_s3_url,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#eksTypes::EksSource

The Amazon EKS configuration, if this input source uses EKS.

Returns:



1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716

class InputSourceSummary < Struct.new(
  :input_source_id,
  :type,
  :resource_tags,
  :cfn_stack_arn,
  :tf_state_file_url,
  :eks,
  :design_file_s3_url,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#input_source_idString

The unique identifier of the input source.

Returns:

  • (String)


1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716

class InputSourceSummary < Struct.new(
  :input_source_id,
  :type,
  :resource_tags,
  :cfn_stack_arn,
  :tf_state_file_url,
  :eks,
  :design_file_s3_url,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#resource_tagsArray<Types::ResourceTag>

The resource tags used for discovery, if this input source uses tags.

Returns:



1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716

class InputSourceSummary < Struct.new(
  :input_source_id,
  :type,
  :resource_tags,
  :cfn_stack_arn,
  :tf_state_file_url,
  :eks,
  :design_file_s3_url,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#tf_state_file_urlString

S3 URL — virtual hosted-style or s3:// URI.

Returns:

  • (String)


1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716

class InputSourceSummary < Struct.new(
  :input_source_id,
  :type,
  :resource_tags,
  :cfn_stack_arn,
  :tf_state_file_url,
  :eks,
  :design_file_s3_url,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the input source.

Returns:

  • (String)


1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716

class InputSourceSummary < Struct.new(
  :input_source_id,
  :type,
  :resource_tags,
  :cfn_stack_arn,
  :tf_state_file_url,
  :eks,
  :design_file_s3_url,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end