Class: Aws::Resiliencehubv2::Types::ListResolvedTestRunTargetResourcesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

Pagination page size.

Returns:

  • (Integer)


2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2415

class ListResolvedTestRunTargetResourcesRequest < Struct.new(
  :test_run_id,
  :service_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Pagination token.

Returns:

  • (String)


2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2415

class ListResolvedTestRunTargetResourcesRequest < Struct.new(
  :test_run_id,
  :service_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnString

The ARN of the service the test run belongs to.

Returns:

  • (String)


2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2415

class ListResolvedTestRunTargetResourcesRequest < Struct.new(
  :test_run_id,
  :service_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#test_run_idString

The identifier of the test run to list resolved target resources for.

Returns:

  • (String)


2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2415

class ListResolvedTestRunTargetResourcesRequest < Struct.new(
  :test_run_id,
  :service_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end