Class: Aws::Resiliencehubv2::Types::ListTestRunDependenciesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::ListTestRunDependenciesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Pagination page size.
-
#next_token ⇒ String
Pagination token.
-
#service_arn ⇒ String
The ARN of the service the test run belongs to.
-
#test_run_id ⇒ String
The identifier of the test run to list dependencies for.
Instance Attribute Details
#max_results ⇒ Integer
Pagination page size.
2837 2838 2839 2840 2841 2842 2843 2844 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2837 class ListTestRunDependenciesRequest < Struct.new( :test_run_id, :service_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Pagination token.
2837 2838 2839 2840 2841 2842 2843 2844 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2837 class ListTestRunDependenciesRequest < Struct.new( :test_run_id, :service_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN of the service the test run belongs to.
2837 2838 2839 2840 2841 2842 2843 2844 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2837 class ListTestRunDependenciesRequest < Struct.new( :test_run_id, :service_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#test_run_id ⇒ String
The identifier of the test run to list dependencies for.
2837 2838 2839 2840 2841 2842 2843 2844 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2837 class ListTestRunDependenciesRequest < Struct.new( :test_run_id, :service_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |