Class: Aws::Resiliencehubv2::Types::ListTestRunEventsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::ListTestRunEventsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ended_at ⇒ Time
Return events at or before this timestamp.
-
#max_results ⇒ Integer
Pagination page size.
-
#next_token ⇒ String
Pagination token.
-
#service_arn ⇒ String
The ARN of the service the test run belongs to.
-
#started_at ⇒ Time
Return events at or after this timestamp.
-
#test_run_id ⇒ String
The identifier of the test run to list events for.
Instance Attribute Details
#ended_at ⇒ Time
Return events at or before this timestamp.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2889 class ListTestRunEventsRequest < Struct.new( :test_run_id, :service_arn, :started_at, :ended_at, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Pagination page size.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2889 class ListTestRunEventsRequest < Struct.new( :test_run_id, :service_arn, :started_at, :ended_at, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Pagination token.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2889 class ListTestRunEventsRequest < Struct.new( :test_run_id, :service_arn, :started_at, :ended_at, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN of the service the test run belongs to.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2889 class ListTestRunEventsRequest < Struct.new( :test_run_id, :service_arn, :started_at, :ended_at, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
Return events at or after this timestamp.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2889 class ListTestRunEventsRequest < Struct.new( :test_run_id, :service_arn, :started_at, :ended_at, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#test_run_id ⇒ String
The identifier of the test run to list events for.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2889 class ListTestRunEventsRequest < Struct.new( :test_run_id, :service_arn, :started_at, :ended_at, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |