Class: Aws::Resiliencehubv2::Types::ListTestRunSourceEventsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

Pagination page size.

Returns:

  • (Integer)


2941
2942
2943
2944
2945
2946
2947
2948
2949
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2941

class ListTestRunSourceEventsRequest < Struct.new(
  :test_run_id,
  :service_arn,
  :source_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Pagination token.

Returns:

  • (String)


2941
2942
2943
2944
2945
2946
2947
2948
2949
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2941

class ListTestRunSourceEventsRequest < Struct.new(
  :test_run_id,
  :service_arn,
  :source_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnString

The ARN of the service the test run belongs to.

Returns:

  • (String)


2941
2942
2943
2944
2945
2946
2947
2948
2949
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2941

class ListTestRunSourceEventsRequest < Struct.new(
  :test_run_id,
  :service_arn,
  :source_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#source_arnString

The ARN of the monitoring source to list events for, such as the ARN of a CloudWatch alarm. If the source was not monitored during the test run, the response is an empty list.

Returns:

  • (String)


2941
2942
2943
2944
2945
2946
2947
2948
2949
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2941

class ListTestRunSourceEventsRequest < Struct.new(
  :test_run_id,
  :service_arn,
  :source_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#test_run_idString

The identifier of the test run to list source events for.

Returns:

  • (String)


2941
2942
2943
2944
2945
2946
2947
2948
2949
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2941

class ListTestRunSourceEventsRequest < Struct.new(
  :test_run_id,
  :service_arn,
  :source_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end