Class: Aws::Resiliencehubv2::Types::ListTestRunSourcesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

Pagination page size.

Returns:

  • (Integer)


2990
2991
2992
2993
2994
2995
2996
2997
2998
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2990

class ListTestRunSourcesRequest < Struct.new(
  :test_run_id,
  :service_arn,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Pagination token.

Returns:

  • (String)


2990
2991
2992
2993
2994
2995
2996
2997
2998
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2990

class ListTestRunSourcesRequest < Struct.new(
  :test_run_id,
  :service_arn,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnString

The ARN of the service the test run belongs to.

Returns:

  • (String)


2990
2991
2992
2993
2994
2995
2996
2997
2998
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2990

class ListTestRunSourcesRequest < Struct.new(
  :test_run_id,
  :service_arn,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#test_run_idString

The identifier of the test run to list sources for.

Returns:

  • (String)


2990
2991
2992
2993
2994
2995
2996
2997
2998
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2990

class ListTestRunSourcesRequest < Struct.new(
  :test_run_id,
  :service_arn,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Filter sources by type.

Returns:

  • (String)


2990
2991
2992
2993
2994
2995
2996
2997
2998
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2990

class ListTestRunSourcesRequest < Struct.new(
  :test_run_id,
  :service_arn,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end