Class: Aws::Resiliencehubv2::Types::ListTestRunsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::ListTestRunsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Pagination page size.
-
#next_token ⇒ String
Pagination token.
-
#service_arn ⇒ String
The ARN of the service to list test runs for.
-
#test_id ⇒ String
Filter test runs by test identifier.
Instance Attribute Details
#max_results ⇒ Integer
Pagination page size.
3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3035 class ListTestRunsRequest < Struct.new( :service_arn, :test_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Pagination token.
3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3035 class ListTestRunsRequest < Struct.new( :service_arn, :test_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN of the service to list test runs for.
3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3035 class ListTestRunsRequest < Struct.new( :service_arn, :test_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#test_id ⇒ String
Filter test runs by test identifier.
3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3035 class ListTestRunsRequest < Struct.new( :service_arn, :test_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |