Class: Aws::Resiliencehubv2::Types::ListTestSourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::ListTestSourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Pagination page size.
-
#next_token ⇒ String
Pagination token.
-
#service_arn ⇒ String
The ARN of the service the test belongs to.
-
#test_id ⇒ String
The identifier of the test to list sources for.
-
#type ⇒ String
Filter sources by type.
Instance Attribute Details
#max_results ⇒ Integer
Pagination page size.
3083 3084 3085 3086 3087 3088 3089 3090 3091 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3083 class ListTestSourcesRequest < Struct.new( :test_id, :service_arn, :type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Pagination token.
3083 3084 3085 3086 3087 3088 3089 3090 3091 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3083 class ListTestSourcesRequest < Struct.new( :test_id, :service_arn, :type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN of the service the test belongs to.
3083 3084 3085 3086 3087 3088 3089 3090 3091 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3083 class ListTestSourcesRequest < Struct.new( :test_id, :service_arn, :type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#test_id ⇒ String
The identifier of the test to list sources for.
3083 3084 3085 3086 3087 3088 3089 3090 3091 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3083 class ListTestSourcesRequest < Struct.new( :test_id, :service_arn, :type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Filter sources by type.
3083 3084 3085 3086 3087 3088 3089 3090 3091 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3083 class ListTestSourcesRequest < Struct.new( :test_id, :service_arn, :type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |