Class: Aws::Resiliencehubv2::Types::PutTestSourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::PutTestSourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service_arn ⇒ String
The ARN of the service the test belongs to.
-
#test_id ⇒ String
The identifier of the test to add sources to.
-
#test_sources ⇒ Array<Types::TestSourceInput>
The monitoring sources to add or update.
Instance Attribute Details
#service_arn ⇒ String
The ARN of the service the test belongs to.
3321 3322 3323 3324 3325 3326 3327 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3321 class PutTestSourcesRequest < Struct.new( :test_id, :service_arn, :test_sources) SENSITIVE = [] include Aws::Structure end |
#test_id ⇒ String
The identifier of the test to add sources to.
3321 3322 3323 3324 3325 3326 3327 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3321 class PutTestSourcesRequest < Struct.new( :test_id, :service_arn, :test_sources) SENSITIVE = [] include Aws::Structure end |
#test_sources ⇒ Array<Types::TestSourceInput>
The monitoring sources to add or update.
3321 3322 3323 3324 3325 3326 3327 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3321 class PutTestSourcesRequest < Struct.new( :test_id, :service_arn, :test_sources) SENSITIVE = [] include Aws::Structure end |