Class: Aws::Resiliencehubv2::Types::ReportOutputConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Note:

ReportOutputConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

ReportOutputConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ReportOutputConfiguration corresponding to the set member.

Configuration for a report output destination.

Defined Under Namespace

Classes: S3, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3Types::S3ReportOutputConfiguration

S3 configuration for report output.



2852
2853
2854
2855
2856
2857
2858
2859
2860
2861
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2852

class ReportOutputConfiguration < Struct.new(
  :s3,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < ReportOutputConfiguration; end
  class Unknown < ReportOutputConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2852
2853
2854
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2852

def unknown
  @unknown
end