Class: Aws::Resiliencehubv2::Types::ResolvedTargetResource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

A single AWS resource that AWS Fault Injection Service (AWS FIS) resolved as a target during a test run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_typeString

The AWS FIS resource type the target belongs to, such as aws:ec2:instance, aws:ecs:task, or aws:eks:pod.

Returns:

  • (String)


3681
3682
3683
3684
3685
3686
3687
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3681

class ResolvedTargetResource < Struct.new(
  :resource_type,
  :target_name,
  :target_information)
  SENSITIVE = []
  include Aws::Structure
end

#target_informationHash<String,String>

The raw target information map as returned by AWS FIS.

Returns:

  • (Hash<String,String>)


3681
3682
3683
3684
3685
3686
3687
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3681

class ResolvedTargetResource < Struct.new(
  :resource_type,
  :target_name,
  :target_information)
  SENSITIVE = []
  include Aws::Structure
end

#target_nameString

The name of the target in the AWS FIS experiment template.

Returns:

  • (String)


3681
3682
3683
3684
3685
3686
3687
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3681

class ResolvedTargetResource < Struct.new(
  :resource_type,
  :target_name,
  :target_information)
  SENSITIVE = []
  include Aws::Structure
end