Class: Aws::Resiliencehubv2::Types::ResourceNotFoundException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Resource not found.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2926

class ResourceNotFoundException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The identifier of the resource that was not found.

Returns:

  • (String)


2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2926

class ResourceNotFoundException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of the resource that was not found.

Returns:

  • (String)


2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2926

class ResourceNotFoundException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end