Class: Aws::Resiliencehubv2::Types::ServiceFunction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Represents a logical component of a service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp when the service function was created.

Returns:

  • (Time)


3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394

class ServiceFunction < Struct.new(
  :service_arn,
  :service_function_id,
  :name,
  :description,
  :criticality,
  :resource_count,
  :source,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#criticalityString

The criticality level of the service function.

Returns:

  • (String)


3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394

class ServiceFunction < Struct.new(
  :service_arn,
  :service_function_id,
  :name,
  :description,
  :criticality,
  :resource_count,
  :source,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Resource description.

Returns:

  • (String)


3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394

class ServiceFunction < Struct.new(
  :service_arn,
  :service_function_id,
  :name,
  :description,
  :criticality,
  :resource_count,
  :source,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Entity label (not part of ARN — spaces allowed).

Returns:

  • (String)


3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394

class ServiceFunction < Struct.new(
  :service_arn,
  :service_function_id,
  :name,
  :description,
  :criticality,
  :resource_count,
  :source,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#resource_countInteger

The number of resources associated with the service function.

Returns:

  • (Integer)


3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394

class ServiceFunction < Struct.new(
  :service_arn,
  :service_function_id,
  :name,
  :description,
  :criticality,
  :resource_count,
  :source,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnString

ARN identifier.

Returns:

  • (String)


3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394

class ServiceFunction < Struct.new(
  :service_arn,
  :service_function_id,
  :name,
  :description,
  :criticality,
  :resource_count,
  :source,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_function_idString

The unique identifier of the service function.

Returns:

  • (String)


3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394

class ServiceFunction < Struct.new(
  :service_arn,
  :service_function_id,
  :name,
  :description,
  :criticality,
  :resource_count,
  :source,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The source of the service function.

Returns:

  • (String)


3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394

class ServiceFunction < Struct.new(
  :service_arn,
  :service_function_id,
  :name,
  :description,
  :criticality,
  :resource_count,
  :source,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp when the service function was last updated.

Returns:

  • (Time)


3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394

class ServiceFunction < Struct.new(
  :service_arn,
  :service_function_id,
  :name,
  :description,
  :criticality,
  :resource_count,
  :source,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end