Class: Aws::Resiliencehubv2::Types::StopCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::StopCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
A CloudWatch alarm that automatically stops a test run if it breaches its threshold.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source ⇒ String
The source of the stop condition.
-
#value ⇒ String
The value of the stop condition, such as the ARN of the CloudWatch alarm.
Instance Attribute Details
#source ⇒ String
The source of the stop condition.
4891 4892 4893 4894 4895 4896 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4891 class StopCondition < Struct.new( :source, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value of the stop condition, such as the ARN of the CloudWatch alarm.
4891 4892 4893 4894 4895 4896 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4891 class StopCondition < Struct.new( :source, :value) SENSITIVE = [] include Aws::Structure end |