Class: Aws::Resiliencehubv2::Types::StopTestRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::StopTestRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service_arn ⇒ String
The ARN of the service the test run belongs to.
-
#test_run_id ⇒ String
The identifier of the test run to stop.
Instance Attribute Details
#service_arn ⇒ String
The ARN of the service the test run belongs to.
4908 4909 4910 4911 4912 4913 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4908 class StopTestRunRequest < Struct.new( :test_run_id, :service_arn) SENSITIVE = [] include Aws::Structure end |
#test_run_id ⇒ String
The identifier of the test run to stop.
4908 4909 4910 4911 4912 4913 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4908 class StopTestRunRequest < Struct.new( :test_run_id, :service_arn) SENSITIVE = [] include Aws::Structure end |