Class: Aws::Resiliencehubv2::Types::SystemServiceAssociatedMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::SystemServiceAssociatedMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Metadata for a system service associated event.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service_arn ⇒ String
ARN identifier.
-
#service_name ⇒ String
The name of the associated service.
-
#user_journeys ⇒ Array<String>
The user journeys linking the service to the system.
Instance Attribute Details
#service_arn ⇒ String
ARN identifier.
4294 4295 4296 4297 4298 4299 4300 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4294 class SystemServiceAssociatedMetadata < Struct.new( :service_name, :service_arn, :user_journeys) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The name of the associated service.
4294 4295 4296 4297 4298 4299 4300 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4294 class SystemServiceAssociatedMetadata < Struct.new( :service_name, :service_arn, :user_journeys) SENSITIVE = [] include Aws::Structure end |
#user_journeys ⇒ Array<String>
The user journeys linking the service to the system.
4294 4295 4296 4297 4298 4299 4300 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4294 class SystemServiceAssociatedMetadata < Struct.new( :service_name, :service_arn, :user_journeys) SENSITIVE = [] include Aws::Structure end |