Class: Aws::Resiliencehubv2::Types::SystemUserJourneyDeletedMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::SystemUserJourneyDeletedMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Metadata for a system user journey deleted event.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_services_at_deletion ⇒ Array<Types::ServiceReference>
The services that were associated at the time of deletion.
-
#user_journey_name ⇒ String
The name of the deleted user journey.
Instance Attribute Details
#associated_services_at_deletion ⇒ Array<Types::ServiceReference>
The services that were associated at the time of deletion.
4341 4342 4343 4344 4345 4346 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4341 class SystemUserJourneyDeletedMetadata < Struct.new( :user_journey_name, :associated_services_at_deletion) SENSITIVE = [] include Aws::Structure end |
#user_journey_name ⇒ String
The name of the deleted user journey.
4341 4342 4343 4344 4345 4346 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4341 class SystemUserJourneyDeletedMetadata < Struct.new( :user_journey_name, :associated_services_at_deletion) SENSITIVE = [] include Aws::Structure end |