Class: Aws::Resiliencehubv2::Types::Test

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Represents a test created for a service by configuring a test template.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<Types::TestAction>

The fault actions the test runs.

Returns:



5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329

class Test < Struct.new(
  :test_id,
  :test_template_arn,
  :service_arn,
  :name,
  :actions,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters,
  :total_test_runs,
  :successful_test_runs,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The timestamp when the test was created.

Returns:

  • (Time)


5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329

class Test < Struct.new(
  :test_id,
  :test_template_arn,
  :service_arn,
  :name,
  :actions,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters,
  :total_test_runs,
  :successful_test_runs,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configurationTypes::LoggingConfiguration

The logging configuration for the test.



5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329

class Test < Struct.new(
  :test_id,
  :test_template_arn,
  :service_arn,
  :name,
  :actions,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters,
  :total_test_runs,
  :successful_test_runs,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the test.

Returns:

  • (String)


5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329

class Test < Struct.new(
  :test_id,
  :test_template_arn,
  :service_arn,
  :name,
  :actions,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters,
  :total_test_runs,
  :successful_test_runs,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,Array<String>>

The parameter values configured for the test.

Returns:

  • (Hash<String,Array<String>>)


5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329

class Test < Struct.new(
  :test_id,
  :test_template_arn,
  :service_arn,
  :name,
  :actions,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters,
  :total_test_runs,
  :successful_test_runs,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#role_nameString

The name of the IAM execution role used to run the test.

Returns:

  • (String)


5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329

class Test < Struct.new(
  :test_id,
  :test_template_arn,
  :service_arn,
  :name,
  :actions,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters,
  :total_test_runs,
  :successful_test_runs,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnString

The ARN of the service the test belongs to.

Returns:

  • (String)


5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329

class Test < Struct.new(
  :test_id,
  :test_template_arn,
  :service_arn,
  :name,
  :actions,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters,
  :total_test_runs,
  :successful_test_runs,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#stop_conditionsArray<Types::StopCondition>

The stop conditions for the test.

Returns:



5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329

class Test < Struct.new(
  :test_id,
  :test_template_arn,
  :service_arn,
  :name,
  :actions,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters,
  :total_test_runs,
  :successful_test_runs,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#successful_test_runsInteger

The number of successful runs of the test.

Returns:

  • (Integer)


5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329

class Test < Struct.new(
  :test_id,
  :test_template_arn,
  :service_arn,
  :name,
  :actions,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters,
  :total_test_runs,
  :successful_test_runs,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#test_idString

The unique identifier of the test.

Returns:

  • (String)


5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329

class Test < Struct.new(
  :test_id,
  :test_template_arn,
  :service_arn,
  :name,
  :actions,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters,
  :total_test_runs,
  :successful_test_runs,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#test_template_arnString

The ARN of the test template the test was created from.

Returns:

  • (String)


5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329

class Test < Struct.new(
  :test_id,
  :test_template_arn,
  :service_arn,
  :name,
  :actions,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters,
  :total_test_runs,
  :successful_test_runs,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#total_test_runsInteger

The total number of runs of the test.

Returns:

  • (Integer)


5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329

class Test < Struct.new(
  :test_id,
  :test_template_arn,
  :service_arn,
  :name,
  :actions,
  :logging_configuration,
  :stop_conditions,
  :role_name,
  :parameters,
  :total_test_runs,
  :successful_test_runs,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end