Class: Aws::Resiliencehubv2::Types::TestRun

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Represents a single run of a test. Configuration is snapshotted from the test and service at the time the run is started.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_targetingString

Indicates whether the test run targets resources in a single AWS account or across multiple accounts.

Returns:

  • (String)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#ended_atTime

The timestamp when the test run ended.

Returns:

  • (Time)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

A human-readable reason for test run failure. Only present when the status is FAILED or ERROR.

Returns:

  • (String)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#event_countInteger

The number of events recorded for the test run. Use ListTestRunEvents to retrieve the details.

Returns:

  • (Integer)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#experimentsArray<Types::ExperimentDetails>

The AWS Fault Injection Service (AWS FIS) experiments run as part of the test run.

Returns:



5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configurationTypes::LoggingConfiguration

The logging configuration snapshotted from the test when the run was started.



5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,Array<String>>

The parameter values used for the test run.

Returns:

  • (Hash<String,Array<String>>)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#permission_modelTypes::PermissionModel

The permission model snapshotted from the service when the run was started.



5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#policyTypes::TestRunPolicySnapshot

The resilience policy snapshotted from the service when the run was started.



5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#region_switch_execution_idString

The identifier of the ARC Region switch execution detected during the test run.

Returns:

  • (String)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#region_switch_plan_arnString

The ARN of the ARC Region switch plan associated with the test run.

Returns:

  • (String)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#regionsArray<String>

The Regions snapshotted from the service when the run was started.

Returns:

  • (Array<String>)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#report_configurationTypes::TestRunReportConfiguration

The report configuration snapshotted from the service when the run was started.



5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#report_outputTypes::ReportGenerationResult

The report generation result for the test run. Present after report generation completes or fails.



5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#role_nameString

The IAM execution role name snapshotted from the test when the run was started.

Returns:

  • (String)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnString

The ARN of the service the test run belongs to.

Returns:

  • (String)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp when the test run started.

Returns:

  • (Time)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the test run.

Returns:

  • (String)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#stop_conditionsArray<Types::StopCondition>

The stop conditions snapshotted from the test when the run was started.

Returns:



5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#test_idString

The identifier of the test that was run.

Returns:

  • (String)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#test_run_idString

The unique identifier of the test run.

Returns:

  • (String)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#test_template_arnString

The ARN of the test template snapshotted from the test when the run was started.

Returns:

  • (String)


5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658

class TestRun < Struct.new(
  :test_run_id,
  :test_id,
  :status,
  :service_arn,
  :started_at,
  :ended_at,
  :experiments,
  :event_count,
  :parameters,
  :error_message,
  :stop_conditions,
  :logging_configuration,
  :role_name,
  :test_template_arn,
  :report_configuration,
  :policy,
  :report_output,
  :region_switch_plan_arn,
  :region_switch_execution_id,
  :permission_model,
  :regions,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end