Class: Aws::Resiliencehubv2::Types::TestRunDependencySummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Contains summary information about a dependency that a test run blocked, as captured when the run started.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#criticalityString

The criticality classification of the dependency when the run started. A dependency that was not discovered has the UNKNOWN criticality.

Returns:

  • (String)


5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727

class TestRunDependencySummary < Struct.new(
  :dependency_id,
  :dependency_name,
  :dns_name,
  :criticality,
  :source,
  :location,
  :source_regions,
  :provider)
  SENSITIVE = []
  include Aws::Structure
end

#dependency_idString

The unique identifier of the dependency. Absent when the dependency was entered manually and was not part of dependency discovery.

Returns:

  • (String)


5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727

class TestRunDependencySummary < Struct.new(
  :dependency_id,
  :dependency_name,
  :dns_name,
  :criticality,
  :source,
  :location,
  :source_regions,
  :provider)
  SENSITIVE = []
  include Aws::Structure
end

#dependency_nameString

The name of the dependency.

Returns:

  • (String)


5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727

class TestRunDependencySummary < Struct.new(
  :dependency_id,
  :dependency_name,
  :dns_name,
  :criticality,
  :source,
  :location,
  :source_regions,
  :provider)
  SENSITIVE = []
  include Aws::Structure
end

#dns_nameString

The DNS name of the dependency that the test run blocked.

Returns:

  • (String)


5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727

class TestRunDependencySummary < Struct.new(
  :dependency_id,
  :dependency_name,
  :dns_name,
  :criticality,
  :source,
  :location,
  :source_regions,
  :provider)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The location of the dependency.

Returns:

  • (String)


5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727

class TestRunDependencySummary < Struct.new(
  :dependency_id,
  :dependency_name,
  :dns_name,
  :criticality,
  :source,
  :location,
  :source_regions,
  :provider)
  SENSITIVE = []
  include Aws::Structure
end

#providerString

The provider of the dependency.

Returns:

  • (String)


5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727

class TestRunDependencySummary < Struct.new(
  :dependency_id,
  :dependency_name,
  :dns_name,
  :criticality,
  :source,
  :location,
  :source_regions,
  :provider)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The origin of the dependency. A discovered dependency was found by dependency discovery; a manual dependency was entered when the run started.

Returns:

  • (String)


5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727

class TestRunDependencySummary < Struct.new(
  :dependency_id,
  :dependency_name,
  :dns_name,
  :criticality,
  :source,
  :location,
  :source_regions,
  :provider)
  SENSITIVE = []
  include Aws::Structure
end

#source_regionsArray<String>

The source Regions from which the dependency was detected.

Returns:

  • (Array<String>)


5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727

class TestRunDependencySummary < Struct.new(
  :dependency_id,
  :dependency_name,
  :dns_name,
  :criticality,
  :source,
  :location,
  :source_regions,
  :provider)
  SENSITIVE = []
  include Aws::Structure
end