Class: Aws::Resiliencehubv2::Types::TestRunPolicySnapshot
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::TestRunPolicySnapshot
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
A snapshot of the resilience policy captured onto a test run from the service when the run was started.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_slo ⇒ Types::AvailabilitySlo
The availability SLO targets.
-
#data_recovery ⇒ Types::DataRecoveryTargets
The data recovery targets.
-
#multi_az ⇒ Types::MultiAzTargets
The multi-AZ resilience targets.
-
#multi_region ⇒ Types::MultiRegionTargets
The multi-Region resilience targets.
-
#name ⇒ String
The name of the policy.
-
#policy_arn ⇒ String
The ARN of the policy.
Instance Attribute Details
#availability_slo ⇒ Types::AvailabilitySlo
The availability SLO targets.
5598 5599 5600 5601 5602 5603 5604 5605 5606 5607 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5598 class TestRunPolicySnapshot < Struct.new( :policy_arn, :name, :availability_slo, :multi_az, :multi_region, :data_recovery) SENSITIVE = [] include Aws::Structure end |
#data_recovery ⇒ Types::DataRecoveryTargets
The data recovery targets.
5598 5599 5600 5601 5602 5603 5604 5605 5606 5607 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5598 class TestRunPolicySnapshot < Struct.new( :policy_arn, :name, :availability_slo, :multi_az, :multi_region, :data_recovery) SENSITIVE = [] include Aws::Structure end |
#multi_az ⇒ Types::MultiAzTargets
The multi-AZ resilience targets.
5598 5599 5600 5601 5602 5603 5604 5605 5606 5607 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5598 class TestRunPolicySnapshot < Struct.new( :policy_arn, :name, :availability_slo, :multi_az, :multi_region, :data_recovery) SENSITIVE = [] include Aws::Structure end |
#multi_region ⇒ Types::MultiRegionTargets
The multi-Region resilience targets.
5598 5599 5600 5601 5602 5603 5604 5605 5606 5607 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5598 class TestRunPolicySnapshot < Struct.new( :policy_arn, :name, :availability_slo, :multi_az, :multi_region, :data_recovery) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the policy.
5598 5599 5600 5601 5602 5603 5604 5605 5606 5607 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5598 class TestRunPolicySnapshot < Struct.new( :policy_arn, :name, :availability_slo, :multi_az, :multi_region, :data_recovery) SENSITIVE = [] include Aws::Structure end |
#policy_arn ⇒ String
The ARN of the policy.
5598 5599 5600 5601 5602 5603 5604 5605 5606 5607 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5598 class TestRunPolicySnapshot < Struct.new( :policy_arn, :name, :availability_slo, :multi_az, :multi_region, :data_recovery) SENSITIVE = [] include Aws::Structure end |