Class: Aws::Resiliencehubv2::Types::TestRunReportConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

A snapshot of the report configuration captured onto a test run from the service when the run was started.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#report_outputArray<Types::ReportOutputConfiguration>

The output destinations for generated reports.



5618
5619
5620
5621
5622
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5618

class TestRunReportConfiguration < Struct.new(
  :report_output)
  SENSITIVE = []
  include Aws::Structure
end