Class: Aws::Resiliencehubv2::Types::TestRunSourceEvent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

A state-change event observed for a test run monitoring source.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detailTypes::TestRunSourceEventDetail

The event payload.



5882
5883
5884
5885
5886
5887
5888
5889
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5882

class TestRunSourceEvent < Struct.new(
  :timestamp,
  :source_arn,
  :event_type,
  :detail)
  SENSITIVE = []
  include Aws::Structure
end

#event_typeString

The type of the event. ALARM indicates an event from a CloudWatch alarm source; the detail member carries either the alarm state change or a collection error.

Returns:

  • (String)


5882
5883
5884
5885
5886
5887
5888
5889
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5882

class TestRunSourceEvent < Struct.new(
  :timestamp,
  :source_arn,
  :event_type,
  :detail)
  SENSITIVE = []
  include Aws::Structure
end

#source_arnString

The ARN of the monitoring source the event belongs to.

Returns:

  • (String)


5882
5883
5884
5885
5886
5887
5888
5889
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5882

class TestRunSourceEvent < Struct.new(
  :timestamp,
  :source_arn,
  :event_type,
  :detail)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The timestamp when the event occurred.

Returns:

  • (Time)


5882
5883
5884
5885
5886
5887
5888
5889
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5882

class TestRunSourceEvent < Struct.new(
  :timestamp,
  :source_arn,
  :event_type,
  :detail)
  SENSITIVE = []
  include Aws::Structure
end