Class: Aws::Resiliencehubv2::Types::TestRunSourceEventDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Note:

TestRunSourceEventDetail is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of TestRunSourceEventDetail corresponding to the set member.

The payload of a test run source event. Exactly one member is set.

Defined Under Namespace

Classes: AlarmStateChange, Error, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alarm_state_changeTypes::AlarmStateChangeDetail

A CloudWatch alarm state change.



5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5905

class TestRunSourceEventDetail < Struct.new(
  :alarm_state_change,
  :error,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AlarmStateChange < TestRunSourceEventDetail; end
  class Error < TestRunSourceEventDetail; end
  class Unknown < TestRunSourceEventDetail; end
end

#errorTypes::TestRunSourceEventError

An error that prevented event collection from the source.



5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5905

class TestRunSourceEventDetail < Struct.new(
  :alarm_state_change,
  :error,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AlarmStateChange < TestRunSourceEventDetail; end
  class Error < TestRunSourceEventDetail; end
  class Unknown < TestRunSourceEventDetail; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



5905
5906
5907
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5905

def unknown
  @unknown
end