Class: Aws::Resiliencehubv2::Types::TestRunSuccessCriteriaAlarmSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Summary information about a success criteria alarm snapshot captured for a test run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The account ID that owns the CloudWatch alarm.

Returns:

  • (String)


5682
5683
5684
5685
5686
5687
5688
5689
5690
5691
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5682

class TestRunSuccessCriteriaAlarmSummary < Struct.new(
  :alarm_arn,
  :alarm_name,
  :region,
  :account_id,
  :outcome,
  :outcome_reason)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_arnString

The ARN of the CloudWatch alarm.

Returns:

  • (String)


5682
5683
5684
5685
5686
5687
5688
5689
5690
5691
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5682

class TestRunSuccessCriteriaAlarmSummary < Struct.new(
  :alarm_arn,
  :alarm_name,
  :region,
  :account_id,
  :outcome,
  :outcome_reason)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_nameString

The name of the CloudWatch alarm.

Returns:

  • (String)


5682
5683
5684
5685
5686
5687
5688
5689
5690
5691
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5682

class TestRunSuccessCriteriaAlarmSummary < Struct.new(
  :alarm_arn,
  :alarm_name,
  :region,
  :account_id,
  :outcome,
  :outcome_reason)
  SENSITIVE = []
  include Aws::Structure
end

#outcomeString

The evaluation outcome of the source. Absent while the source has not yet been evaluated; set to the terminal outcome afterwards.

Returns:

  • (String)


5682
5683
5684
5685
5686
5687
5688
5689
5690
5691
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5682

class TestRunSuccessCriteriaAlarmSummary < Struct.new(
  :alarm_arn,
  :alarm_name,
  :region,
  :account_id,
  :outcome,
  :outcome_reason)
  SENSITIVE = []
  include Aws::Structure
end

#outcome_reasonString

A human-readable reason for the outcome.

Returns:

  • (String)


5682
5683
5684
5685
5686
5687
5688
5689
5690
5691
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5682

class TestRunSuccessCriteriaAlarmSummary < Struct.new(
  :alarm_arn,
  :alarm_name,
  :region,
  :account_id,
  :outcome,
  :outcome_reason)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Region of the CloudWatch alarm.

Returns:

  • (String)


5682
5683
5684
5685
5686
5687
5688
5689
5690
5691
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5682

class TestRunSuccessCriteriaAlarmSummary < Struct.new(
  :alarm_arn,
  :alarm_name,
  :region,
  :account_id,
  :outcome,
  :outcome_reason)
  SENSITIVE = []
  include Aws::Structure
end