Class: Aws::Resiliencehubv2::Types::TestRunSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Contains summary information about a test run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_targetingString

Indicates whether the test run targets resources in a single AWS account or across multiple accounts.

Returns:

  • (String)


6045
6046
6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#ended_atTime

The timestamp when the test run ended.

Returns:

  • (Time)


6045
6046
6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

A human-readable reason for test run failure. Only present when the status is FAILED or ERROR.

Returns:

  • (String)


6045
6046
6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnString

The ARN of the service the test run belongs to.

Returns:

  • (String)


6045
6046
6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp when the test run started.

Returns:

  • (Time)


6045
6046
6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the test run.

Returns:

  • (String)


6045
6046
6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#test_run_idString

The unique identifier of the test run.

Returns:

  • (String)


6045
6046
6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#test_template_arnString

The ARN of the test template the test run was based on.

Returns:

  • (String)


6045
6046
6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end