Class: Aws::Resiliencehubv2::Types::UserJourney

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Represents a user journey that defines a critical path through a system.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp when the user journey was created.

Returns:

  • (Time)


6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6443

class UserJourney < Struct.new(
  :user_journey_id,
  :name,
  :description,
  :policy_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Resource description.

Returns:

  • (String)


6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6443

class UserJourney < Struct.new(
  :user_journey_id,
  :name,
  :description,
  :policy_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Entity label (not part of ARN — spaces allowed).

Returns:

  • (String)


6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6443

class UserJourney < Struct.new(
  :user_journey_id,
  :name,
  :description,
  :policy_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#policy_arnString

ARN identifier.

Returns:

  • (String)


6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6443

class UserJourney < Struct.new(
  :user_journey_id,
  :name,
  :description,
  :policy_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp when the user journey was last updated.

Returns:

  • (Time)


6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6443

class UserJourney < Struct.new(
  :user_journey_id,
  :name,
  :description,
  :policy_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#user_journey_idString

The unique identifier of the user journey.

Returns:

  • (String)


6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6443

class UserJourney < Struct.new(
  :user_journey_id,
  :name,
  :description,
  :policy_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end