Class: Aws::Resiliencehubv2::Types::UserJourneyChanges
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::UserJourneyChanges
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Describes changes made to a user journey.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_services ⇒ Types::ServiceReferenceChanges
Changes to the services associated with the user journey.
-
#journey_description ⇒ Types::StringChange
Changes to the user journey description.
Instance Attribute Details
#associated_services ⇒ Types::ServiceReferenceChanges
Changes to the services associated with the user journey.
4966 4967 4968 4969 4970 4971 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4966 class UserJourneyChanges < Struct.new( :journey_description, :associated_services) SENSITIVE = [] include Aws::Structure end |
#journey_description ⇒ Types::StringChange
Changes to the user journey description.
4966 4967 4968 4969 4970 4971 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4966 class UserJourneyChanges < Struct.new( :journey_description, :associated_services) SENSITIVE = [] include Aws::Structure end |