Class: Aws::Resiliencehubv2::Types::UserJourneySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::UserJourneySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Contains summary information about a user journey.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the user journey was created.
-
#name ⇒ String
Entity label (not part of ARN — spaces allowed).
-
#updated_at ⇒ Time
The timestamp when the user journey was last updated.
-
#user_journey_id ⇒ String
The unique identifier of the user journey.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the user journey was created.
4918 4919 4920 4921 4922 4923 4924 4925 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4918 class UserJourneySummary < Struct.new( :user_journey_id, :name, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Entity label (not part of ARN — spaces allowed).
4918 4919 4920 4921 4922 4923 4924 4925 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4918 class UserJourneySummary < Struct.new( :user_journey_id, :name, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the user journey was last updated.
4918 4919 4920 4921 4922 4923 4924 4925 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4918 class UserJourneySummary < Struct.new( :user_journey_id, :name, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#user_journey_id ⇒ String
The unique identifier of the user journey.
4918 4919 4920 4921 4922 4923 4924 4925 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4918 class UserJourneySummary < Struct.new( :user_journey_id, :name, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |