Class: Aws::Resiliencehubv2::Waiters::FailureModeAssessmentSuccess

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-resiliencehubv2/waiters.rb,
sig/waiters.rbs

Overview

Wait until a failure mode assessment completes successfully

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ FailureModeAssessmentSuccess

Returns a new instance of FailureModeAssessmentSuccess.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 5
  • :delay (Integer) — default: 30
  • :before_attempt (Proc)
  • :before_wait (Proc)


88
89
# File 'lib/aws-sdk-resiliencehubv2/waiters.rb', line 88

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



126
127
128
# File 'lib/aws-sdk-resiliencehubv2/waiters.rb', line 126

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::ListFailureModeAssessmentsResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :service_arn (required, String)

    ARN identifier.

  • :assessment_statuses (Array<String>)

    Specifies the assessment statuses to include in the results.

  • :started_after (Time, DateTime, Date, Integer, String)

    Specifies that only assessments that started at or after this timestamp appear in the results.

  • :ended_before (Time, DateTime, Date, Integer, String)

    Specifies that only assessments that ended at or before this timestamp appear in the results.

  • :sort_by (String)

    The field to use for sorting failure mode assessments.

  • :sort_order (String)

    The sort order for results.

  • :max_results (Integer)

    Pagination page size.

  • :next_token (String)

    Pagination token.

Returns:



121
# File 'lib/aws-sdk-resiliencehubv2/waiters.rb', line 121

def wait: (