Class: Aws::Resiliencehubv2::Waiters::ServiceAssessmentCompleted
- Inherits:
-
Object
- Object
- Aws::Resiliencehubv2::Waiters::ServiceAssessmentCompleted
- Defined in:
- lib/aws-sdk-resiliencehubv2/waiters.rb
Overview
Wait until a service assessment completes successfully
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ServiceAssessmentCompleted
constructor
A new instance of ServiceAssessmentCompleted.
-
#wait(params = {}) ⇒ Types::GetServiceResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ServiceAssessmentCompleted
Returns a new instance of ServiceAssessmentCompleted.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/aws-sdk-resiliencehubv2/waiters.rb', line 190 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_service, acceptors: [ { "matcher" => "path", "argument" => "service.assessment_status", "state" => "success", "expected" => "SUCCESS" }, { "matcher" => "path", "argument" => "service.assessment_status", "state" => "failure", "expected" => "FAILED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
222 223 224 |
# File 'lib/aws-sdk-resiliencehubv2/waiters.rb', line 222 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetServiceResponse
Returns a response object which responds to the following methods:
-
#service => Types::Service
217 218 219 |
# File 'lib/aws-sdk-resiliencehubv2/waiters.rb', line 217 def wait(params = {}) @waiter.wait(client: @client, params: params) end |