Class: Aws::Resiliencehubv2::Waiters::ServiceResourceDiscoveryCompleted
- Inherits:
-
Object
- Object
- Aws::Resiliencehubv2::Waiters::ServiceResourceDiscoveryCompleted
- Defined in:
- lib/aws-sdk-resiliencehubv2/waiters.rb
Overview
Wait until service resource discovery completes
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ServiceResourceDiscoveryCompleted
constructor
A new instance of ServiceResourceDiscoveryCompleted.
-
#wait(params = {}) ⇒ Types::GetServiceResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ServiceResourceDiscoveryCompleted
Returns a new instance of ServiceResourceDiscoveryCompleted.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/aws-sdk-resiliencehubv2/waiters.rb', line 235 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_service, acceptors: [ { "matcher" => "path", "argument" => "service.resource_discovery.status", "state" => "success", "expected" => "SUCCEEDED" }, { "matcher" => "path", "argument" => "service.resource_discovery.status", "state" => "success", "expected" => "COMPLETED_WITH_FAILURES" }, { "matcher" => "path", "argument" => "service.resource_discovery.status", "state" => "failure", "expected" => "FAILED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
273 274 275 |
# File 'lib/aws-sdk-resiliencehubv2/waiters.rb', line 273 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetServiceResponse
Returns a response object which responds to the following methods:
-
#service => Types::Service
268 269 270 |
# File 'lib/aws-sdk-resiliencehubv2/waiters.rb', line 268 def wait(params = {}) @waiter.wait(client: @client, params: params) end |