Class: Aws::Resiliencehubv2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Resiliencehubv2::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-resiliencehubv2/client.rb,
sig/client.rbs
Overview
An API client for Resiliencehubv2. To construct a client, you need to configure a :region and :credentials.
client = Aws::Resiliencehubv2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateAssertionResponseSuccess, _CreateInputSourceResponseSuccess, _CreatePolicyResponseSuccess, _CreateReportResponseSuccess, _CreateServiceFunctionResourcesResponseSuccess, _CreateServiceFunctionResponseSuccess, _CreateServiceResponseSuccess, _CreateSystemResponseSuccess, _CreateTestResponseSuccess, _CreateUserJourneyResponseSuccess, _DeleteAssertionResponseSuccess, _DeleteInputSourceResponseSuccess, _DeletePolicyResponseSuccess, _DeleteServiceFunctionResourcesResponseSuccess, _DeleteServiceFunctionResponseSuccess, _DeleteServiceResponseSuccess, _DeleteSystemResponseSuccess, _DeleteTestResponseSuccess, _DeleteTestSourcesResponseSuccess, _DeleteUserJourneyResponseSuccess, _GetFailureModeFindingResponseSuccess, _GetPolicyResponseSuccess, _GetServiceResponseSuccess, _GetSystemResponseSuccess, _GetTestResponseSuccess, _GetTestRunResponseSuccess, _GetTestTemplateResponseSuccess, _GetUserJourneyResponseSuccess, _ImportAppResponseSuccess, _ImportPolicyResponseSuccess, _ListAssertionsResponseSuccess, _ListDependenciesResponseSuccess, _ListFailureModeAssessmentsResponseSuccess, _ListFailureModeFindingsResponseSuccess, _ListInputSourcesResponseSuccess, _ListPoliciesResponseSuccess, _ListReportsResponseSuccess, _ListResolvedTestRunTargetResourcesResponseSuccess, _ListResourcesResponseSuccess, _ListServiceEventsResponseSuccess, _ListServiceFunctionsResponseSuccess, _ListServiceTopologyEdgesResponseSuccess, _ListServicesResponseSuccess, _ListSystemEventsResponseSuccess, _ListSystemsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTestRunEventsResponseSuccess, _ListTestRunSourcesResponseSuccess, _ListTestRunsResponseSuccess, _ListTestSourcesResponseSuccess, _ListTestTemplatesResponseSuccess, _ListTestsResponseSuccess, _ListUserJourneysResponseSuccess, _PutTestSourcesResponseSuccess, _StartFailureModeAssessmentResponseSuccess, _StartTestRunResponseSuccess, _StopTestRunResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAssertionResponseSuccess, _UpdateDependencyResponseSuccess, _UpdateFailureModeFindingResponseSuccess, _UpdatePolicyResponseSuccess, _UpdateServiceFunctionResponseSuccess, _UpdateServiceResponseSuccess, _UpdateSystemResponseSuccess, _UpdateTestResponseSuccess, _UpdateUserJourneyResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_assertion(params = {}) ⇒ Types::CreateAssertionResponse
Creates a resilience assertion for a service.
-
#create_input_source(params = {}) ⇒ Types::CreateInputSourceResponse
Creates an input source for a service.
-
#create_policy(params = {}) ⇒ Types::CreatePolicyResponse
Creates a resilience policy that defines availability and disaster recovery requirements.
-
#create_report(params = {}) ⇒ Types::CreateReportResponse
On-demand report creation.
-
#create_service(params = {}) ⇒ Types::CreateServiceResponse
Creates a service.
-
#create_service_function(params = {}) ⇒ Types::CreateServiceFunctionResponse
Creates a service function within a service.
-
#create_service_function_resources(params = {}) ⇒ Types::CreateServiceFunctionResourcesResponse
Associates resources with a service function.
-
#create_system(params = {}) ⇒ Types::CreateSystemResponse
Creates a system that represents a logical grouping of services.
-
#create_test(params = {}) ⇒ Types::CreateTestResponse
Creates a test for a service by configuring a test template.
-
#create_user_journey(params = {}) ⇒ Types::CreateUserJourneyResponse
Creates a user journey within a system.
-
#delete_assertion(params = {}) ⇒ Types::DeleteAssertionResponse
Deletes a resilience assertion from a service.
-
#delete_input_source(params = {}) ⇒ Types::DeleteInputSourceResponse
Deletes an input source.
-
#delete_policy(params = {}) ⇒ Types::DeletePolicyResponse
Deletes a resilience policy.
-
#delete_service(params = {}) ⇒ Types::DeleteServiceResponse
Deletes a service.
-
#delete_service_function(params = {}) ⇒ Types::DeleteServiceFunctionResponse
Deletes a service function.
-
#delete_service_function_resources(params = {}) ⇒ Types::DeleteServiceFunctionResourcesResponse
Removes resources from a service function.
-
#delete_system(params = {}) ⇒ Types::DeleteSystemResponse
Deletes a system.
-
#delete_test(params = {}) ⇒ Types::DeleteTestResponse
Deletes a test.
-
#delete_test_sources(params = {}) ⇒ Struct
Removes monitoring sources from a test.
-
#delete_user_journey(params = {}) ⇒ Types::DeleteUserJourneyResponse
Deletes a user journey.
-
#get_failure_mode_finding(params = {}) ⇒ Types::GetFailureModeFindingResponse
Retrieves a finding by findingId.
-
#get_policy(params = {}) ⇒ Types::GetPolicyResponse
Retrieves a resilience policy by ARN.
-
#get_service(params = {}) ⇒ Types::GetServiceResponse
Retrieves a service by ARN.
-
#get_system(params = {}) ⇒ Types::GetSystemResponse
Retrieves a system by ARN.
-
#get_test(params = {}) ⇒ Types::GetTestResponse
Retrieves a test by ID.
-
#get_test_run(params = {}) ⇒ Types::GetTestRunResponse
Retrieves a test run by ID, including its status, results, and the configuration snapshotted when the run started.
-
#get_test_template(params = {}) ⇒ Types::GetTestTemplateResponse
Retrieves a resilience test template by ARN, including the parameters it accepts and the fault actions it runs.
-
#get_user_journey(params = {}) ⇒ Types::GetUserJourneyResponse
Retrieves a user journey.
-
#import_app(params = {}) ⇒ Types::ImportAppResponse
Imports a V1 app into the V2 resource model, creating a service with the same name.
-
#import_policy(params = {}) ⇒ Types::ImportPolicyResponse
Imports a V1 policy into V2, mapping RTO/RPO values from V1 scenarios.
-
#list_assertions(params = {}) ⇒ Types::ListAssertionsResponse
Lists resilience assertions for a service.
-
#list_dependencies(params = {}) ⇒ Types::ListDependenciesResponse
Lists dependencies discovered for services.
-
#list_failure_mode_assessments(params = {}) ⇒ Types::ListFailureModeAssessmentsResponse
Lists failure mode assessments.
-
#list_failure_mode_findings(params = {}) ⇒ Types::ListFailureModeFindingsResponse
List findings.
-
#list_input_sources(params = {}) ⇒ Types::ListInputSourcesResponse
Lists input sources for a service.
-
#list_policies(params = {}) ⇒ Types::ListPoliciesResponse
Lists resilience policies.
-
#list_reports(params = {}) ⇒ Types::ListReportsResponse
List reports for a service, or all reports owned by the account if serviceArn is not provided.
-
#list_resolved_test_run_target_resources(params = {}) ⇒ Types::ListResolvedTestRunTargetResourcesResponse
Lists the AWS resources that AWS Fault Injection Service (AWS FIS) resolved as targets for a test run.
-
#list_resources(params = {}) ⇒ Types::ListResourcesResponse
List resources.
-
#list_service_events(params = {}) ⇒ Types::ListServiceEventsResponse
Lists events for a service.
-
#list_service_functions(params = {}) ⇒ Types::ListServiceFunctionsResponse
Lists service functions for a service.
-
#list_service_topology_edges(params = {}) ⇒ Types::ListServiceTopologyEdgesResponse
Lists topology edges for a service.
-
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists services.
-
#list_system_events(params = {}) ⇒ Types::ListSystemEventsResponse
Lists events for a system.
-
#list_systems(params = {}) ⇒ Types::ListSystemsResponse
Lists systems.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a resource.
-
#list_test_run_events(params = {}) ⇒ Types::ListTestRunEventsResponse
Lists the events in a test run's timeline.
-
#list_test_run_sources(params = {}) ⇒ Types::ListTestRunSourcesResponse
Lists the monitoring source snapshots captured for a test run, optionally filtered by type.
-
#list_test_runs(params = {}) ⇒ Types::ListTestRunsResponse
Lists the runs of a test, or all test runs for a service.
-
#list_test_sources(params = {}) ⇒ Types::ListTestSourcesResponse
Lists the monitoring sources attached to a test, optionally filtered by type.
-
#list_test_templates(params = {}) ⇒ Types::ListTestTemplatesResponse
Lists the available resilience test templates.
-
#list_tests(params = {}) ⇒ Types::ListTestsResponse
Lists the tests configured for a service.
-
#list_user_journeys(params = {}) ⇒ Types::ListUserJourneysResponse
Lists user journeys for a system.
-
#put_test_sources(params = {}) ⇒ Struct
Adds or updates the monitoring sources on a test.
-
#start_failure_mode_assessment(params = {}) ⇒ Types::StartFailureModeAssessmentResponse
Starts a failure mode assessment.
-
#start_test_run(params = {}) ⇒ Types::StartTestRunResponse
Starts a run of a test.
-
#stop_test_run(params = {}) ⇒ Types::StopTestRunResponse
Stops an in-progress test run.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_assertion(params = {}) ⇒ Types::UpdateAssertionResponse
Updates a resilience assertion.
-
#update_dependency(params = {}) ⇒ Types::UpdateDependencyResponse
Updates a dependency classification.
-
#update_failure_mode_finding(params = {}) ⇒ Types::UpdateFailureModeFindingResponse
Updates an existing finding.
-
#update_policy(params = {}) ⇒ Types::UpdatePolicyResponse
Updates an existing resilience policy.
-
#update_service(params = {}) ⇒ Types::UpdateServiceResponse
Updates an existing service.
-
#update_service_function(params = {}) ⇒ Types::UpdateServiceFunctionResponse
Updates a service function.
-
#update_system(params = {}) ⇒ Types::UpdateSystemResponse
Updates an existing system.
-
#update_test(params = {}) ⇒ Types::UpdateTestResponse
Updates the configuration of an existing test.
-
#update_user_journey(params = {}) ⇒ Types::UpdateUserJourneyResponse
Updates an existing user journey.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-resiliencehubv2/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4478 4479 4480 |
# File 'lib/aws-sdk-resiliencehubv2/client.rb', line 4478 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4481 4482 4483 |
# File 'lib/aws-sdk-resiliencehubv2/client.rb', line 4481 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 4344 4345 4346 4347 4348 |
# File 'lib/aws-sdk-resiliencehubv2/client.rb', line 4332 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Resiliencehubv2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-resiliencehubv2' context[:gem_version] = '1.3.0' Seahorse::Client::Request.new(handlers, context) end |
#create_assertion(params = {}) ⇒ Types::CreateAssertionResponse
Creates a resilience assertion for a service.
86 |
# File 'sig/client.rbs', line 86
def create_assertion: (
|
#create_input_source(params = {}) ⇒ Types::CreateInputSourceResponse
Creates an input source for a service.
99 |
# File 'sig/client.rbs', line 99
def create_input_source: (
|
#create_policy(params = {}) ⇒ Types::CreatePolicyResponse
Creates a resilience policy that defines availability and disaster recovery requirements.
125 |
# File 'sig/client.rbs', line 125
def create_policy: (
|
#create_report(params = {}) ⇒ Types::CreateReportResponse
On-demand report creation. Idempotent — duplicate requests with same clientToken return existing result.
155 |
# File 'sig/client.rbs', line 155
def create_report: (
|
#create_service(params = {}) ⇒ Types::CreateServiceResponse
Creates a service.
167 |
# File 'sig/client.rbs', line 167
def create_service: (
|
#create_service_function(params = {}) ⇒ Types::CreateServiceFunctionResponse
Creates a service function within a service.
201 |
# File 'sig/client.rbs', line 201
def create_service_function: (
|
#create_service_function_resources(params = {}) ⇒ Types::CreateServiceFunctionResourcesResponse
Associates resources with a service function.
217 |
# File 'sig/client.rbs', line 217
def create_service_function_resources: (
|
#create_system(params = {}) ⇒ Types::CreateSystemResponse
Creates a system that represents a logical grouping of services.
229 |
# File 'sig/client.rbs', line 229
def create_system: (
|
#create_test(params = {}) ⇒ Types::CreateTestResponse
Creates a test for a service by configuring a test template. Each service has one test per template.
244 |
# File 'sig/client.rbs', line 244
def create_test: (
|
#create_user_journey(params = {}) ⇒ Types::CreateUserJourneyResponse
Creates a user journey within a system.
268 |
# File 'sig/client.rbs', line 268
def create_user_journey: (
|
#delete_assertion(params = {}) ⇒ Types::DeleteAssertionResponse
Deletes a resilience assertion from a service.
282 |
# File 'sig/client.rbs', line 282
def delete_assertion: (
|
#delete_input_source(params = {}) ⇒ Types::DeleteInputSourceResponse
Deletes an input source.
294 |
# File 'sig/client.rbs', line 294
def delete_input_source: (
|
#delete_policy(params = {}) ⇒ Types::DeletePolicyResponse
Deletes a resilience policy.
305 |
# File 'sig/client.rbs', line 305
def delete_policy: (
|
#delete_service(params = {}) ⇒ Types::DeleteServiceResponse
Deletes a service.
315 |
# File 'sig/client.rbs', line 315
def delete_service: (
|
#delete_service_function(params = {}) ⇒ Types::DeleteServiceFunctionResponse
Deletes a service function.
325 |
# File 'sig/client.rbs', line 325
def delete_service_function: (
|
#delete_service_function_resources(params = {}) ⇒ Types::DeleteServiceFunctionResourcesResponse
Removes resources from a service function.
338 |
# File 'sig/client.rbs', line 338
def delete_service_function_resources: (
|
#delete_system(params = {}) ⇒ Types::DeleteSystemResponse
Deletes a system.
350 |
# File 'sig/client.rbs', line 350
def delete_system: (
|
#delete_test(params = {}) ⇒ Types::DeleteTestResponse
Deletes a test.
360 |
# File 'sig/client.rbs', line 360
def delete_test: (
|
#delete_test_sources(params = {}) ⇒ Struct
Removes monitoring sources from a test. The operation is transactional and idempotent — removing a source that is not attached is a no-op.
370 |
# File 'sig/client.rbs', line 370
def delete_test_sources: (
|
#delete_user_journey(params = {}) ⇒ Types::DeleteUserJourneyResponse
Deletes a user journey.
384 |
# File 'sig/client.rbs', line 384
def delete_user_journey: (
|
#get_failure_mode_finding(params = {}) ⇒ Types::GetFailureModeFindingResponse
Retrieves a finding by findingId.
395 |
# File 'sig/client.rbs', line 395
def get_failure_mode_finding: (
|
#get_policy(params = {}) ⇒ Types::GetPolicyResponse
Retrieves a resilience policy by ARN.
406 |
# File 'sig/client.rbs', line 406
def get_policy: (
|
#get_service(params = {}) ⇒ Types::GetServiceResponse
Retrieves a service by ARN.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* service_assessment_completed
* service_resource_discovery_completed
416 |
# File 'sig/client.rbs', line 416
def get_service: (
|
#get_system(params = {}) ⇒ Types::GetSystemResponse
Retrieves a system by ARN.
426 |
# File 'sig/client.rbs', line 426
def get_system: (
|
#get_test(params = {}) ⇒ Types::GetTestResponse
Retrieves a test by ID.
436 |
# File 'sig/client.rbs', line 436
def get_test: (
|
#get_test_run(params = {}) ⇒ Types::GetTestRunResponse
Retrieves a test run by ID, including its status, results, and the configuration snapshotted when the run started.
447 |
# File 'sig/client.rbs', line 447
def get_test_run: (
|
#get_test_template(params = {}) ⇒ Types::GetTestTemplateResponse
Retrieves a resilience test template by ARN, including the parameters it accepts and the fault actions it runs.
458 |
# File 'sig/client.rbs', line 458
def get_test_template: (
|
#get_user_journey(params = {}) ⇒ Types::GetUserJourneyResponse
Retrieves a user journey.
468 |
# File 'sig/client.rbs', line 468
def get_user_journey: (
|
#import_app(params = {}) ⇒ Types::ImportAppResponse
Imports a V1 app into the V2 resource model, creating a service with the same name.
479 |
# File 'sig/client.rbs', line 479
def import_app: (
|
#import_policy(params = {}) ⇒ Types::ImportPolicyResponse
Imports a V1 policy into V2, mapping RTO/RPO values from V1 scenarios.
501 |
# File 'sig/client.rbs', line 501
def import_policy: (
|
#list_assertions(params = {}) ⇒ Types::ListAssertionsResponse
Lists resilience assertions for a service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
520 |
# File 'sig/client.rbs', line 520
def list_assertions: (
|
#list_dependencies(params = {}) ⇒ Types::ListDependenciesResponse
Lists dependencies discovered for services.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
534 |
# File 'sig/client.rbs', line 534
def list_dependencies: (
|
#list_failure_mode_assessments(params = {}) ⇒ Types::ListFailureModeAssessmentsResponse
Lists failure mode assessments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* failure_mode_assessment_success
550 |
# File 'sig/client.rbs', line 550
def list_failure_mode_assessments: (
|
#list_failure_mode_findings(params = {}) ⇒ Types::ListFailureModeFindingsResponse
List findings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
568 |
# File 'sig/client.rbs', line 568
def list_failure_mode_findings: (
|
#list_input_sources(params = {}) ⇒ Types::ListInputSourcesResponse
Lists input sources for a service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
584 |
# File 'sig/client.rbs', line 584
def list_input_sources: (
|
#list_policies(params = {}) ⇒ Types::ListPoliciesResponse
Lists resilience policies.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
598 |
# File 'sig/client.rbs', line 598
def list_policies: (
|
#list_reports(params = {}) ⇒ Types::ListReportsResponse
List reports for a service, or all reports owned by the account if serviceArn is not provided.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* report_succeeded
610 |
# File 'sig/client.rbs', line 610
def list_reports: (
|
#list_resolved_test_run_target_resources(params = {}) ⇒ Types::ListResolvedTestRunTargetResourcesResponse
Lists the AWS resources that AWS Fault Injection Service (AWS FIS) resolved as targets for a test run.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
625 |
# File 'sig/client.rbs', line 625
def list_resolved_test_run_target_resources: (
|
#list_resources(params = {}) ⇒ Types::ListResourcesResponse
List resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
640 |
# File 'sig/client.rbs', line 640
def list_resources: (
|
#list_service_events(params = {}) ⇒ Types::ListServiceEventsResponse
Lists events for a service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
657 |
# File 'sig/client.rbs', line 657
def list_service_events: (
|
#list_service_functions(params = {}) ⇒ Types::ListServiceFunctionsResponse
Lists service functions for a service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
673 |
# File 'sig/client.rbs', line 673
def list_service_functions: (
|
#list_service_topology_edges(params = {}) ⇒ Types::ListServiceTopologyEdgesResponse
Lists topology edges for a service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
686 |
# File 'sig/client.rbs', line 686
def list_service_topology_edges: (
|
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists services.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
699 |
# File 'sig/client.rbs', line 699
def list_services: (
|
#list_system_events(params = {}) ⇒ Types::ListSystemEventsResponse
Lists events for a system.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
717 |
# File 'sig/client.rbs', line 717
def list_system_events: (
|
#list_systems(params = {}) ⇒ Types::ListSystemsResponse
Lists systems.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
733 |
# File 'sig/client.rbs', line 733
def list_systems: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a resource.
745 |
# File 'sig/client.rbs', line 745
def list_tags_for_resource: (
|
#list_test_run_events(params = {}) ⇒ Types::ListTestRunEventsResponse
Lists the events in a test run's timeline.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
756 |
# File 'sig/client.rbs', line 756
def list_test_run_events: (
|
#list_test_run_sources(params = {}) ⇒ Types::ListTestRunSourcesResponse
Lists the monitoring source snapshots captured for a test run, optionally filtered by type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
772 |
# File 'sig/client.rbs', line 772
def list_test_run_sources: (
|
#list_test_runs(params = {}) ⇒ Types::ListTestRunsResponse
Lists the runs of a test, or all test runs for a service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
787 |
# File 'sig/client.rbs', line 787
def list_test_runs: (
|
#list_test_sources(params = {}) ⇒ Types::ListTestSourcesResponse
Lists the monitoring sources attached to a test, optionally filtered by type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
801 |
# File 'sig/client.rbs', line 801
def list_test_sources: (
|
#list_test_templates(params = {}) ⇒ Types::ListTestTemplatesResponse
Lists the available resilience test templates. A test template is a pre-configured, AWS recommended test that defines which resilience capability to validate.
815 |
# File 'sig/client.rbs', line 815
def list_test_templates: (
|
#list_tests(params = {}) ⇒ Types::ListTestsResponse
Lists the tests configured for a service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
825 |
# File 'sig/client.rbs', line 825
def list_tests: (
|
#list_user_journeys(params = {}) ⇒ Types::ListUserJourneysResponse
Lists user journeys for a system.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
838 |
# File 'sig/client.rbs', line 838
def list_user_journeys: (
|
#put_test_sources(params = {}) ⇒ Struct
Adds or updates the monitoring sources on a test. The operation is transactional — either every source is written or the call fails and nothing is written.
849 |
# File 'sig/client.rbs', line 849
def put_test_sources: (
|
#start_failure_mode_assessment(params = {}) ⇒ Types::StartFailureModeAssessmentResponse
Starts a failure mode assessment.
866 |
# File 'sig/client.rbs', line 866
def start_failure_mode_assessment: (
|
#start_test_run(params = {}) ⇒ Types::StartTestRunResponse
Starts a run of a test. Each run scopes to the current resources in the service and produces a pass or fail outcome.
879 |
# File 'sig/client.rbs', line 879
def start_test_run: (
|
#stop_test_run(params = {}) ⇒ Types::StopTestRunResponse
Stops an in-progress test run.
891 |
# File 'sig/client.rbs', line 891
def stop_test_run: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
901 |
# File 'sig/client.rbs', line 901
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
911 |
# File 'sig/client.rbs', line 911
def untag_resource: (
|
#update_assertion(params = {}) ⇒ Types::UpdateAssertionResponse
Updates a resilience assertion.
922 |
# File 'sig/client.rbs', line 922
def update_assertion: (
|
#update_dependency(params = {}) ⇒ Types::UpdateDependencyResponse
Updates a dependency classification.
940 |
# File 'sig/client.rbs', line 940
def update_dependency: (
|
#update_failure_mode_finding(params = {}) ⇒ Types::UpdateFailureModeFindingResponse
Updates an existing finding.
953 |
# File 'sig/client.rbs', line 953
def update_failure_mode_finding: (
|
#update_policy(params = {}) ⇒ Types::UpdatePolicyResponse
Updates an existing resilience policy.
966 |
# File 'sig/client.rbs', line 966
def update_policy: (
|
#update_service(params = {}) ⇒ Types::UpdateServiceResponse
Updates an existing service.
993 |
# File 'sig/client.rbs', line 993
def update_service: (
|
#update_service_function(params = {}) ⇒ Types::UpdateServiceFunctionResponse
Updates a service function.
1024 |
# File 'sig/client.rbs', line 1024
def update_service_function: (
|
#update_system(params = {}) ⇒ Types::UpdateSystemResponse
Updates an existing system.
1038 |
# File 'sig/client.rbs', line 1038
def update_system: (
|
#update_test(params = {}) ⇒ Types::UpdateTestResponse
Updates the configuration of an existing test.
1050 |
# File 'sig/client.rbs', line 1050
def update_test: (
|
#update_user_journey(params = {}) ⇒ Types::UpdateUserJourneyResponse
Updates an existing user journey.
1074 |
# File 'sig/client.rbs', line 1074
def update_user_journey: (
|
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
Basic Usage
A waiter will call an API operation until:
- It is successful
- It enters a terminal state
- It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
Valid Waiters
The following table lists the valid waiter names, the operations they call,
and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts |
|---|---|---|---|
| failure_mode_assessment_success | #list_failure_mode_assessments | 30 | 5 |
| report_succeeded | #list_reports | 30 | 5 |
| service_assessment_completed | #get_service | 30 | 5 |
| service_resource_discovery_completed | #get_service | 30 | 5 |
1084 |
# File 'sig/client.rbs', line 1084
def wait_until: (:failure_mode_assessment_success waiter_name,
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4449 4450 4451 |
# File 'lib/aws-sdk-resiliencehubv2/client.rb', line 4449 def waiter_names waiters.keys end |