Class: Aws::Resiliencehubv2::Types::AlarmStateChangeDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::AlarmStateChangeDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Details about a CloudWatch alarm state change observed during a test run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#previous_state ⇒ String
The state the alarm transitioned from.
-
#reason ⇒ String
A human-readable explanation of the state change, as reported by CloudWatch.
-
#state ⇒ String
The state the alarm transitioned to.
Instance Attribute Details
#previous_state ⇒ String
The state the alarm transitioned from. Absent on the initial event, which records the alarm's state when collection began.
79 80 81 82 83 84 85 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 79 class AlarmStateChangeDetail < Struct.new( :state, :previous_state, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
A human-readable explanation of the state change, as reported by CloudWatch.
79 80 81 82 83 84 85 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 79 class AlarmStateChangeDetail < Struct.new( :state, :previous_state, :reason) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state the alarm transitioned to.
79 80 81 82 83 84 85 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 79 class AlarmStateChangeDetail < Struct.new( :state, :previous_state, :reason) SENSITIVE = [] include Aws::Structure end |