Class: Aws::Resiliencehubv2::Types::CreateServiceFunctionResourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::CreateServiceFunctionResourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resources ⇒ Array<String>
The list of resources to associate with the service function.
-
#service_arn ⇒ String
ARN identifier.
-
#service_function_id ⇒ String
The identifier of the service function to associate resources with.
Instance Attribute Details
#resources ⇒ Array<String>
The list of resources to associate with the service function.
528 529 530 531 532 533 534 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 528 class CreateServiceFunctionResourcesRequest < Struct.new( :service_arn, :service_function_id, :resources) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
ARN identifier.
528 529 530 531 532 533 534 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 528 class CreateServiceFunctionResourcesRequest < Struct.new( :service_arn, :service_function_id, :resources) SENSITIVE = [] include Aws::Structure end |
#service_function_id ⇒ String
The identifier of the service function to associate resources with.
528 529 530 531 532 533 534 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 528 class CreateServiceFunctionResourcesRequest < Struct.new( :service_arn, :service_function_id, :resources) SENSITIVE = [] include Aws::Structure end |