Class: Aws::Resiliencehubv2::Types::CreateTestRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::CreateTestRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#logging_configuration ⇒ Types::LoggingConfiguration
The logging configuration for the test.
-
#parameters ⇒ Hash<String,Array<String>>
The parameter values for the test.
-
#role_name ⇒ String
The name of the IAM execution role to use when running the test.
-
#service_arn ⇒ String
The ARN of the service to create the test for.
-
#stop_conditions ⇒ Array<Types::StopCondition>
The stop conditions for the test.
-
#test_template_arn ⇒ String
The ARN of the test template to configure.
Instance Attribute Details
#logging_configuration ⇒ Types::LoggingConfiguration
The logging configuration for the test.
734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 734 class CreateTestRequest < Struct.new( :service_arn, :test_template_arn, :logging_configuration, :stop_conditions, :role_name, :parameters) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Array<String>>
The parameter values for the test.
734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 734 class CreateTestRequest < Struct.new( :service_arn, :test_template_arn, :logging_configuration, :stop_conditions, :role_name, :parameters) SENSITIVE = [] include Aws::Structure end |
#role_name ⇒ String
The name of the IAM execution role to use when running the test.
734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 734 class CreateTestRequest < Struct.new( :service_arn, :test_template_arn, :logging_configuration, :stop_conditions, :role_name, :parameters) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN of the service to create the test for.
734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 734 class CreateTestRequest < Struct.new( :service_arn, :test_template_arn, :logging_configuration, :stop_conditions, :role_name, :parameters) SENSITIVE = [] include Aws::Structure end |
#stop_conditions ⇒ Array<Types::StopCondition>
The stop conditions for the test.
734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 734 class CreateTestRequest < Struct.new( :service_arn, :test_template_arn, :logging_configuration, :stop_conditions, :role_name, :parameters) SENSITIVE = [] include Aws::Structure end |
#test_template_arn ⇒ String
The ARN of the test template to configure.
734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 734 class CreateTestRequest < Struct.new( :service_arn, :test_template_arn, :logging_configuration, :stop_conditions, :role_name, :parameters) SENSITIVE = [] include Aws::Structure end |