Class: Aws::Resiliencehubv2::Types::EksLabelSelector
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::EksLabelSelector
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
A label selector that filters the Kubernetes objects discovered from an Amazon EKS input source. An object must satisfy both matchLabels and matchExpressions to match the selector. A selector with neither matches every object. The selector must render to 2,048 characters or fewer in Kubernetes label selector syntax.
Constant Summary collapse
- SENSITIVE =
[:match_labels, :match_expressions]
Instance Attribute Summary collapse
-
#match_expressions ⇒ Array<Types::EksLabelSelectorRequirement>
The label requirements that an object must satisfy.
-
#match_labels ⇒ Hash<String,String>
The label key-value pairs that an object must have.
Instance Attribute Details
#match_expressions ⇒ Array<Types::EksLabelSelectorRequirement>
The label requirements that an object must satisfy. All requirements in the list must match for the object to be selected.
1365 1366 1367 1368 1369 1370 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1365 class EksLabelSelector < Struct.new( :match_labels, :match_expressions) SENSITIVE = [:match_labels, :match_expressions] include Aws::Structure end |
#match_labels ⇒ Hash<String,String>
The label key-value pairs that an object must have. All pairs must match for the object to be selected.
1365 1366 1367 1368 1369 1370 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1365 class EksLabelSelector < Struct.new( :match_labels, :match_expressions) SENSITIVE = [:match_labels, :match_expressions] include Aws::Structure end |