Class: Aws::Resiliencehubv2::Types::FailedReportOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::FailedReportOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Details when report generation failed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_code ⇒ String
The error code describing why the report generation failed.
-
#error_message ⇒ String
The error message describing why the report generation failed.
Instance Attribute Details
#error_code ⇒ String
The error code describing why the report generation failed.
1260 1261 1262 1263 1264 1265 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1260 class FailedReportOutput < Struct.new( :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message describing why the report generation failed.
1260 1261 1262 1263 1264 1265 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1260 class FailedReportOutput < Struct.new( :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |