Class: Aws::Resiliencehubv2::Types::InputSourceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::InputSourceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Contains summary information about an input source for a service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cfn_stack_arn ⇒ String
ARN identifier.
-
#created_at ⇒ Time
The timestamp when the input source was created.
-
#design_file_s3_url ⇒ String
S3 URL — virtual hosted-style or s3:// URI.
-
#eks ⇒ Types::EksSource
The Amazon EKS configuration, if this input source uses EKS.
-
#input_source_id ⇒ String
The unique identifier of the input source.
-
#resource_tags ⇒ Array<Types::ResourceTag>
The resource tags used for discovery, if this input source uses tags.
-
#tf_state_file_url ⇒ String
S3 URL — virtual hosted-style or s3:// URI.
-
#type ⇒ String
The type of the input source.
Instance Attribute Details
#cfn_stack_arn ⇒ String
ARN identifier.
1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716 class InputSourceSummary < Struct.new( :input_source_id, :type, :resource_tags, :cfn_stack_arn, :tf_state_file_url, :eks, :design_file_s3_url, :created_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the input source was created.
1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716 class InputSourceSummary < Struct.new( :input_source_id, :type, :resource_tags, :cfn_stack_arn, :tf_state_file_url, :eks, :design_file_s3_url, :created_at) SENSITIVE = [] include Aws::Structure end |
#design_file_s3_url ⇒ String
S3 URL — virtual hosted-style or s3:// URI.
1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716 class InputSourceSummary < Struct.new( :input_source_id, :type, :resource_tags, :cfn_stack_arn, :tf_state_file_url, :eks, :design_file_s3_url, :created_at) SENSITIVE = [] include Aws::Structure end |
#eks ⇒ Types::EksSource
The Amazon EKS configuration, if this input source uses EKS.
1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716 class InputSourceSummary < Struct.new( :input_source_id, :type, :resource_tags, :cfn_stack_arn, :tf_state_file_url, :eks, :design_file_s3_url, :created_at) SENSITIVE = [] include Aws::Structure end |
#input_source_id ⇒ String
The unique identifier of the input source.
1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716 class InputSourceSummary < Struct.new( :input_source_id, :type, :resource_tags, :cfn_stack_arn, :tf_state_file_url, :eks, :design_file_s3_url, :created_at) SENSITIVE = [] include Aws::Structure end |
#resource_tags ⇒ Array<Types::ResourceTag>
The resource tags used for discovery, if this input source uses tags.
1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716 class InputSourceSummary < Struct.new( :input_source_id, :type, :resource_tags, :cfn_stack_arn, :tf_state_file_url, :eks, :design_file_s3_url, :created_at) SENSITIVE = [] include Aws::Structure end |
#tf_state_file_url ⇒ String
S3 URL — virtual hosted-style or s3:// URI.
1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716 class InputSourceSummary < Struct.new( :input_source_id, :type, :resource_tags, :cfn_stack_arn, :tf_state_file_url, :eks, :design_file_s3_url, :created_at) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the input source.
1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 1716 class InputSourceSummary < Struct.new( :input_source_id, :type, :resource_tags, :cfn_stack_arn, :tf_state_file_url, :eks, :design_file_s3_url, :created_at) SENSITIVE = [] include Aws::Structure end |