Class: Aws::Resiliencehubv2::Types::ListResolvedTestRunTargetResourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::ListResolvedTestRunTargetResourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Pagination page size.
-
#next_token ⇒ String
Pagination token.
-
#service_arn ⇒ String
The ARN of the service the test run belongs to.
-
#test_run_id ⇒ String
The identifier of the test run to list resolved target resources for.
Instance Attribute Details
#max_results ⇒ Integer
Pagination page size.
2415 2416 2417 2418 2419 2420 2421 2422 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2415 class ListResolvedTestRunTargetResourcesRequest < Struct.new( :test_run_id, :service_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Pagination token.
2415 2416 2417 2418 2419 2420 2421 2422 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2415 class ListResolvedTestRunTargetResourcesRequest < Struct.new( :test_run_id, :service_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN of the service the test run belongs to.
2415 2416 2417 2418 2419 2420 2421 2422 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2415 class ListResolvedTestRunTargetResourcesRequest < Struct.new( :test_run_id, :service_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#test_run_id ⇒ String
The identifier of the test run to list resolved target resources for.
2415 2416 2417 2418 2419 2420 2421 2422 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2415 class ListResolvedTestRunTargetResourcesRequest < Struct.new( :test_run_id, :service_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |