Class: Aws::Resiliencehubv2::Types::ListTestRunSourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::ListTestRunSourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Pagination page size.
-
#next_token ⇒ String
Pagination token.
-
#service_arn ⇒ String
The ARN of the service the test run belongs to.
-
#test_run_id ⇒ String
The identifier of the test run to list sources for.
-
#type ⇒ String
Filter sources by type.
Instance Attribute Details
#max_results ⇒ Integer
Pagination page size.
2990 2991 2992 2993 2994 2995 2996 2997 2998 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2990 class ListTestRunSourcesRequest < Struct.new( :test_run_id, :service_arn, :type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Pagination token.
2990 2991 2992 2993 2994 2995 2996 2997 2998 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2990 class ListTestRunSourcesRequest < Struct.new( :test_run_id, :service_arn, :type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN of the service the test run belongs to.
2990 2991 2992 2993 2994 2995 2996 2997 2998 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2990 class ListTestRunSourcesRequest < Struct.new( :test_run_id, :service_arn, :type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#test_run_id ⇒ String
The identifier of the test run to list sources for.
2990 2991 2992 2993 2994 2995 2996 2997 2998 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2990 class ListTestRunSourcesRequest < Struct.new( :test_run_id, :service_arn, :type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Filter sources by type.
2990 2991 2992 2993 2994 2995 2996 2997 2998 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2990 class ListTestRunSourcesRequest < Struct.new( :test_run_id, :service_arn, :type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |