Class: Aws::Resiliencehubv2::Types::ReportOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Note:

ReportOutput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ReportOutput corresponding to the set member.

Union of possible report outputs.

Defined Under Namespace

Classes: FailedReportOutput, S3ReportOutput, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failed_report_outputTypes::FailedReportOutput

Details when report generation failed.



2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2827

class ReportOutput < Struct.new(
  :s3_report_output,
  :failed_report_output,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3ReportOutput < ReportOutput; end
  class FailedReportOutput < ReportOutput; end
  class Unknown < ReportOutput; end
end

#s3_report_outputTypes::S3ReportOutput

The S3 location where the report was written.



2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2827

class ReportOutput < Struct.new(
  :s3_report_output,
  :failed_report_output,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3ReportOutput < ReportOutput; end
  class FailedReportOutput < ReportOutput; end
  class Unknown < ReportOutput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2827
2828
2829
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2827

def unknown
  @unknown
end