Class: Aws::Resiliencehubv2::Types::ReportOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::ReportOutput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Note:
ReportOutput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ReportOutput corresponding to the set member.
Union of possible report outputs.
Direct Known Subclasses
Defined Under Namespace
Classes: FailedReportOutput, S3ReportOutput, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failed_report_output ⇒ Types::FailedReportOutput
Details when report generation failed.
-
#s3_report_output ⇒ Types::S3ReportOutput
The S3 location where the report was written.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#failed_report_output ⇒ Types::FailedReportOutput
Details when report generation failed.
2772 2773 2774 2775 2776 2777 2778 2779 2780 2781 2782 2783 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2772 class ReportOutput < Struct.new( :s3_report_output, :failed_report_output, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3ReportOutput < ReportOutput; end class FailedReportOutput < ReportOutput; end class Unknown < ReportOutput; end end |
#s3_report_output ⇒ Types::S3ReportOutput
The S3 location where the report was written.
2772 2773 2774 2775 2776 2777 2778 2779 2780 2781 2782 2783 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2772 class ReportOutput < Struct.new( :s3_report_output, :failed_report_output, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3ReportOutput < ReportOutput; end class FailedReportOutput < ReportOutput; end class Unknown < ReportOutput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2772 2773 2774 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2772 def unknown @unknown end |