Class: Aws::Resiliencehubv2::Types::ReportOutputConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Note:

ReportOutputConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

ReportOutputConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ReportOutputConfiguration corresponding to the set member.

Configuration for a report output destination.

Direct Known Subclasses

S3, Unknown

Defined Under Namespace

Classes: S3, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3Types::S3ReportOutputConfiguration

S3 configuration for report output.



2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2797

class ReportOutputConfiguration < Struct.new(
  :s3,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < ReportOutputConfiguration; end
  class Unknown < ReportOutputConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2797
2798
2799
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2797

def unknown
  @unknown
end