Class: Aws::Resiliencehubv2::Types::ResourceNotFoundException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::ResourceNotFoundException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Resource not found.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#resource_id ⇒ String
The identifier of the resource that was not found.
-
#resource_type ⇒ String
The type of the resource that was not found.
Instance Attribute Details
#message ⇒ String
2926 2927 2928 2929 2930 2931 2932 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2926 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The identifier of the resource that was not found.
2926 2927 2928 2929 2930 2931 2932 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2926 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the resource that was not found.
2926 2927 2928 2929 2930 2931 2932 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 2926 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |