Class: Aws::Resiliencehubv2::Types::ServiceFunction
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::ServiceFunction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Represents a logical component of a service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the service function was created.
-
#criticality ⇒ String
The criticality level of the service function.
-
#description ⇒ String
Resource description.
-
#name ⇒ String
Entity label (not part of ARN — spaces allowed).
-
#resource_count ⇒ Integer
The number of resources associated with the service function.
-
#service_arn ⇒ String
ARN identifier.
-
#service_function_id ⇒ String
The unique identifier of the service function.
-
#source ⇒ String
The source of the service function.
-
#updated_at ⇒ Time
The timestamp when the service function was last updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the service function was created.
3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394 class ServiceFunction < Struct.new( :service_arn, :service_function_id, :name, :description, :criticality, :resource_count, :source, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#criticality ⇒ String
The criticality level of the service function.
3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394 class ServiceFunction < Struct.new( :service_arn, :service_function_id, :name, :description, :criticality, :resource_count, :source, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Resource description.
3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394 class ServiceFunction < Struct.new( :service_arn, :service_function_id, :name, :description, :criticality, :resource_count, :source, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Entity label (not part of ARN — spaces allowed).
3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394 class ServiceFunction < Struct.new( :service_arn, :service_function_id, :name, :description, :criticality, :resource_count, :source, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#resource_count ⇒ Integer
The number of resources associated with the service function.
3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394 class ServiceFunction < Struct.new( :service_arn, :service_function_id, :name, :description, :criticality, :resource_count, :source, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
ARN identifier.
3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394 class ServiceFunction < Struct.new( :service_arn, :service_function_id, :name, :description, :criticality, :resource_count, :source, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#service_function_id ⇒ String
The unique identifier of the service function.
3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394 class ServiceFunction < Struct.new( :service_arn, :service_function_id, :name, :description, :criticality, :resource_count, :source, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The source of the service function.
3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394 class ServiceFunction < Struct.new( :service_arn, :service_function_id, :name, :description, :criticality, :resource_count, :source, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the service function was last updated.
3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 3394 class ServiceFunction < Struct.new( :service_arn, :service_function_id, :name, :description, :criticality, :resource_count, :source, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |