Class: Aws::Resiliencehubv2::Types::StopTestRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::StopTestRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service_arn ⇒ String
The ARN of the service the test run belongs to.
-
#test_run_id ⇒ String
The identifier of the test run to stop.
Instance Attribute Details
#service_arn ⇒ String
The ARN of the service the test run belongs to.
4727 4728 4729 4730 4731 4732 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4727 class StopTestRunRequest < Struct.new( :test_run_id, :service_arn) SENSITIVE = [] include Aws::Structure end |
#test_run_id ⇒ String
The identifier of the test run to stop.
4727 4728 4729 4730 4731 4732 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4727 class StopTestRunRequest < Struct.new( :test_run_id, :service_arn) SENSITIVE = [] include Aws::Structure end |