Class: Aws::Resiliencehubv2::Types::Test
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::Test
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Represents a test created for a service by configuring a test template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::TestAction>
The fault actions the test runs.
-
#creation_time ⇒ Time
The timestamp when the test was created.
-
#logging_configuration ⇒ Types::LoggingConfiguration
The logging configuration for the test.
-
#name ⇒ String
The name of the test.
-
#parameters ⇒ Hash<String,Array<String>>
The parameter values configured for the test.
-
#role_name ⇒ String
The name of the IAM execution role used to run the test.
-
#service_arn ⇒ String
The ARN of the service the test belongs to.
-
#stop_conditions ⇒ Array<Types::StopCondition>
The stop conditions for the test.
-
#successful_test_runs ⇒ Integer
The number of successful runs of the test.
-
#test_id ⇒ String
The unique identifier of the test.
-
#test_template_arn ⇒ String
The ARN of the test template the test was created from.
-
#total_test_runs ⇒ Integer
The total number of runs of the test.
Instance Attribute Details
#actions ⇒ Array<Types::TestAction>
The fault actions the test runs.
5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329 class Test < Struct.new( :test_id, :test_template_arn, :service_arn, :name, :actions, :logging_configuration, :stop_conditions, :role_name, :parameters, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp when the test was created.
5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329 class Test < Struct.new( :test_id, :test_template_arn, :service_arn, :name, :actions, :logging_configuration, :stop_conditions, :role_name, :parameters, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::LoggingConfiguration
The logging configuration for the test.
5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329 class Test < Struct.new( :test_id, :test_template_arn, :service_arn, :name, :actions, :logging_configuration, :stop_conditions, :role_name, :parameters, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the test.
5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329 class Test < Struct.new( :test_id, :test_template_arn, :service_arn, :name, :actions, :logging_configuration, :stop_conditions, :role_name, :parameters, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Array<String>>
The parameter values configured for the test.
5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329 class Test < Struct.new( :test_id, :test_template_arn, :service_arn, :name, :actions, :logging_configuration, :stop_conditions, :role_name, :parameters, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#role_name ⇒ String
The name of the IAM execution role used to run the test.
5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329 class Test < Struct.new( :test_id, :test_template_arn, :service_arn, :name, :actions, :logging_configuration, :stop_conditions, :role_name, :parameters, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN of the service the test belongs to.
5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329 class Test < Struct.new( :test_id, :test_template_arn, :service_arn, :name, :actions, :logging_configuration, :stop_conditions, :role_name, :parameters, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#stop_conditions ⇒ Array<Types::StopCondition>
The stop conditions for the test.
5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329 class Test < Struct.new( :test_id, :test_template_arn, :service_arn, :name, :actions, :logging_configuration, :stop_conditions, :role_name, :parameters, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#successful_test_runs ⇒ Integer
The number of successful runs of the test.
5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329 class Test < Struct.new( :test_id, :test_template_arn, :service_arn, :name, :actions, :logging_configuration, :stop_conditions, :role_name, :parameters, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#test_id ⇒ String
The unique identifier of the test.
5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329 class Test < Struct.new( :test_id, :test_template_arn, :service_arn, :name, :actions, :logging_configuration, :stop_conditions, :role_name, :parameters, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#test_template_arn ⇒ String
The ARN of the test template the test was created from.
5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329 class Test < Struct.new( :test_id, :test_template_arn, :service_arn, :name, :actions, :logging_configuration, :stop_conditions, :role_name, :parameters, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#total_test_runs ⇒ Integer
The total number of runs of the test.
5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5329 class Test < Struct.new( :test_id, :test_template_arn, :service_arn, :name, :actions, :logging_configuration, :stop_conditions, :role_name, :parameters, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |