Class: Aws::Resiliencehubv2::Types::TestRun
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::TestRun
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Represents a single run of a test. Configuration is snapshotted from the test and service at the time the run is started.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_targeting ⇒ String
Indicates whether the test run targets resources in a single AWS account or across multiple accounts.
-
#ended_at ⇒ Time
The timestamp when the test run ended.
-
#error_message ⇒ String
A human-readable reason for test run failure.
-
#event_count ⇒ Integer
The number of events recorded for the test run.
-
#experiments ⇒ Array<Types::ExperimentDetails>
The AWS Fault Injection Service (AWS FIS) experiments run as part of the test run.
-
#logging_configuration ⇒ Types::LoggingConfiguration
The logging configuration snapshotted from the test when the run was started.
-
#parameters ⇒ Hash<String,Array<String>>
The parameter values used for the test run.
-
#permission_model ⇒ Types::PermissionModel
The permission model snapshotted from the service when the run was started.
-
#policy ⇒ Types::TestRunPolicySnapshot
The resilience policy snapshotted from the service when the run was started.
-
#region_switch_execution_id ⇒ String
The identifier of the ARC Region switch execution detected during the test run.
-
#region_switch_plan_arn ⇒ String
The ARN of the ARC Region switch plan associated with the test run.
-
#regions ⇒ Array<String>
The Regions snapshotted from the service when the run was started.
-
#report_configuration ⇒ Types::TestRunReportConfiguration
The report configuration snapshotted from the service when the run was started.
-
#report_output ⇒ Types::ReportGenerationResult
The report generation result for the test run.
-
#role_name ⇒ String
The IAM execution role name snapshotted from the test when the run was started.
-
#service_arn ⇒ String
The ARN of the service the test run belongs to.
-
#started_at ⇒ Time
The timestamp when the test run started.
-
#status ⇒ String
The current status of the test run.
-
#stop_conditions ⇒ Array<Types::StopCondition>
The stop conditions snapshotted from the test when the run was started.
-
#test_id ⇒ String
The identifier of the test that was run.
-
#test_run_id ⇒ String
The unique identifier of the test run.
-
#test_template_arn ⇒ String
The ARN of the test template snapshotted from the test when the run was started.
Instance Attribute Details
#account_targeting ⇒ String
Indicates whether the test run targets resources in a single AWS account or across multiple accounts.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The timestamp when the test run ended.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
A human-readable reason for test run failure. Only present when the status is FAILED or ERROR.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#event_count ⇒ Integer
The number of events recorded for the test run. Use ListTestRunEvents to retrieve the details.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#experiments ⇒ Array<Types::ExperimentDetails>
The AWS Fault Injection Service (AWS FIS) experiments run as part of the test run.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::LoggingConfiguration
The logging configuration snapshotted from the test when the run was started.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Array<String>>
The parameter values used for the test run.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#permission_model ⇒ Types::PermissionModel
The permission model snapshotted from the service when the run was started.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#policy ⇒ Types::TestRunPolicySnapshot
The resilience policy snapshotted from the service when the run was started.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#region_switch_execution_id ⇒ String
The identifier of the ARC Region switch execution detected during the test run.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#region_switch_plan_arn ⇒ String
The ARN of the ARC Region switch plan associated with the test run.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#regions ⇒ Array<String>
The Regions snapshotted from the service when the run was started.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#report_configuration ⇒ Types::TestRunReportConfiguration
The report configuration snapshotted from the service when the run was started.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#report_output ⇒ Types::ReportGenerationResult
The report generation result for the test run. Present after report generation completes or fails.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#role_name ⇒ String
The IAM execution role name snapshotted from the test when the run was started.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN of the service the test run belongs to.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp when the test run started.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the test run.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#stop_conditions ⇒ Array<Types::StopCondition>
The stop conditions snapshotted from the test when the run was started.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#test_id ⇒ String
The identifier of the test that was run.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#test_run_id ⇒ String
The unique identifier of the test run.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#test_template_arn ⇒ String
The ARN of the test template snapshotted from the test when the run was started.
5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5658 class TestRun < Struct.new( :test_run_id, :test_id, :status, :service_arn, :started_at, :ended_at, :experiments, :event_count, :parameters, :error_message, :stop_conditions, :logging_configuration, :role_name, :test_template_arn, :report_configuration, :policy, :report_output, :region_switch_plan_arn, :region_switch_execution_id, :permission_model, :regions, :account_targeting) SENSITIVE = [] include Aws::Structure end |