Class: Aws::Resiliencehubv2::Types::TestRunDependencySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::TestRunDependencySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Contains summary information about a dependency that a test run blocked, as captured when the run started.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#criticality ⇒ String
The criticality classification of the dependency when the run started.
-
#dependency_id ⇒ String
The unique identifier of the dependency.
-
#dependency_name ⇒ String
The name of the dependency.
-
#dns_name ⇒ String
The DNS name of the dependency that the test run blocked.
-
#location ⇒ String
The location of the dependency.
-
#provider ⇒ String
The provider of the dependency.
-
#source ⇒ String
The origin of the dependency.
-
#source_regions ⇒ Array<String>
The source Regions from which the dependency was detected.
Instance Attribute Details
#criticality ⇒ String
The criticality classification of the dependency when the run started. A dependency that was not discovered has the UNKNOWN criticality.
5727 5728 5729 5730 5731 5732 5733 5734 5735 5736 5737 5738 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727 class TestRunDependencySummary < Struct.new( :dependency_id, :dependency_name, :dns_name, :criticality, :source, :location, :source_regions, :provider) SENSITIVE = [] include Aws::Structure end |
#dependency_id ⇒ String
The unique identifier of the dependency. Absent when the dependency was entered manually and was not part of dependency discovery.
5727 5728 5729 5730 5731 5732 5733 5734 5735 5736 5737 5738 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727 class TestRunDependencySummary < Struct.new( :dependency_id, :dependency_name, :dns_name, :criticality, :source, :location, :source_regions, :provider) SENSITIVE = [] include Aws::Structure end |
#dependency_name ⇒ String
The name of the dependency.
5727 5728 5729 5730 5731 5732 5733 5734 5735 5736 5737 5738 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727 class TestRunDependencySummary < Struct.new( :dependency_id, :dependency_name, :dns_name, :criticality, :source, :location, :source_regions, :provider) SENSITIVE = [] include Aws::Structure end |
#dns_name ⇒ String
The DNS name of the dependency that the test run blocked.
5727 5728 5729 5730 5731 5732 5733 5734 5735 5736 5737 5738 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727 class TestRunDependencySummary < Struct.new( :dependency_id, :dependency_name, :dns_name, :criticality, :source, :location, :source_regions, :provider) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location of the dependency.
5727 5728 5729 5730 5731 5732 5733 5734 5735 5736 5737 5738 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727 class TestRunDependencySummary < Struct.new( :dependency_id, :dependency_name, :dns_name, :criticality, :source, :location, :source_regions, :provider) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ String
The provider of the dependency.
5727 5728 5729 5730 5731 5732 5733 5734 5735 5736 5737 5738 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727 class TestRunDependencySummary < Struct.new( :dependency_id, :dependency_name, :dns_name, :criticality, :source, :location, :source_regions, :provider) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The origin of the dependency. A discovered dependency was found by dependency discovery; a manual dependency was entered when the run started.
5727 5728 5729 5730 5731 5732 5733 5734 5735 5736 5737 5738 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727 class TestRunDependencySummary < Struct.new( :dependency_id, :dependency_name, :dns_name, :criticality, :source, :location, :source_regions, :provider) SENSITIVE = [] include Aws::Structure end |
#source_regions ⇒ Array<String>
The source Regions from which the dependency was detected.
5727 5728 5729 5730 5731 5732 5733 5734 5735 5736 5737 5738 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5727 class TestRunDependencySummary < Struct.new( :dependency_id, :dependency_name, :dns_name, :criticality, :source, :location, :source_regions, :provider) SENSITIVE = [] include Aws::Structure end |