Class: Aws::Resiliencehubv2::Types::TestRunSourceEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::TestRunSourceEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
A state-change event observed for a test run monitoring source.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detail ⇒ Types::TestRunSourceEventDetail
The event payload.
-
#event_type ⇒ String
The type of the event.
-
#source_arn ⇒ String
The ARN of the monitoring source the event belongs to.
-
#timestamp ⇒ Time
The timestamp when the event occurred.
Instance Attribute Details
#detail ⇒ Types::TestRunSourceEventDetail
The event payload.
5882 5883 5884 5885 5886 5887 5888 5889 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5882 class TestRunSourceEvent < Struct.new( :timestamp, :source_arn, :event_type, :detail) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ String
The type of the event. ALARM indicates an event from a CloudWatch alarm source; the detail member carries either the alarm state change or a collection error.
5882 5883 5884 5885 5886 5887 5888 5889 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5882 class TestRunSourceEvent < Struct.new( :timestamp, :source_arn, :event_type, :detail) SENSITIVE = [] include Aws::Structure end |
#source_arn ⇒ String
The ARN of the monitoring source the event belongs to.
5882 5883 5884 5885 5886 5887 5888 5889 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5882 class TestRunSourceEvent < Struct.new( :timestamp, :source_arn, :event_type, :detail) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Time
The timestamp when the event occurred.
5882 5883 5884 5885 5886 5887 5888 5889 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5882 class TestRunSourceEvent < Struct.new( :timestamp, :source_arn, :event_type, :detail) SENSITIVE = [] include Aws::Structure end |