Class: Aws::Resiliencehubv2::Types::TestRunSuccessCriteriaAlarmSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::TestRunSuccessCriteriaAlarmSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Summary information about a success criteria alarm snapshot captured for a test run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account ID that owns the CloudWatch alarm.
-
#alarm_arn ⇒ String
The ARN of the CloudWatch alarm.
-
#alarm_name ⇒ String
The name of the CloudWatch alarm.
-
#outcome ⇒ String
The evaluation outcome of the source.
-
#outcome_reason ⇒ String
A human-readable reason for the outcome.
-
#region ⇒ String
The Region of the CloudWatch alarm.
Instance Attribute Details
#account_id ⇒ String
The account ID that owns the CloudWatch alarm.
5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5682 class TestRunSuccessCriteriaAlarmSummary < Struct.new( :alarm_arn, :alarm_name, :region, :account_id, :outcome, :outcome_reason) SENSITIVE = [] include Aws::Structure end |
#alarm_arn ⇒ String
The ARN of the CloudWatch alarm.
5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5682 class TestRunSuccessCriteriaAlarmSummary < Struct.new( :alarm_arn, :alarm_name, :region, :account_id, :outcome, :outcome_reason) SENSITIVE = [] include Aws::Structure end |
#alarm_name ⇒ String
The name of the CloudWatch alarm.
5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5682 class TestRunSuccessCriteriaAlarmSummary < Struct.new( :alarm_arn, :alarm_name, :region, :account_id, :outcome, :outcome_reason) SENSITIVE = [] include Aws::Structure end |
#outcome ⇒ String
The evaluation outcome of the source. Absent while the source has not yet been evaluated; set to the terminal outcome afterwards.
5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5682 class TestRunSuccessCriteriaAlarmSummary < Struct.new( :alarm_arn, :alarm_name, :region, :account_id, :outcome, :outcome_reason) SENSITIVE = [] include Aws::Structure end |
#outcome_reason ⇒ String
A human-readable reason for the outcome.
5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5682 class TestRunSuccessCriteriaAlarmSummary < Struct.new( :alarm_arn, :alarm_name, :region, :account_id, :outcome, :outcome_reason) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Region of the CloudWatch alarm.
5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5682 class TestRunSuccessCriteriaAlarmSummary < Struct.new( :alarm_arn, :alarm_name, :region, :account_id, :outcome, :outcome_reason) SENSITIVE = [] include Aws::Structure end |