Class: Aws::Resiliencehubv2::Types::TestRunSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Contains summary information about a test run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_targetingString

Indicates whether this test run targets a single account or multiple accounts.

Returns:

  • (String)


5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
5741
5742
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#ended_atTime

The timestamp when the test run ended.

Returns:

  • (Time)


5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
5741
5742
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

A human-readable reason for test run failure. Only present when the status is FAILED or ERROR.

Returns:

  • (String)


5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
5741
5742
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnString

The ARN of the service the test run belongs to.

Returns:

  • (String)


5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
5741
5742
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp when the test run started.

Returns:

  • (Time)


5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
5741
5742
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the test run.

Returns:

  • (String)


5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
5741
5742
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#test_run_idString

The unique identifier of the test run.

Returns:

  • (String)


5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
5741
5742
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end

#test_template_arnString

The ARN of the test template the test run was based on.

Returns:

  • (String)


5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
5741
5742
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731

class TestRunSummary < Struct.new(
  :test_run_id,
  :status,
  :started_at,
  :ended_at,
  :test_template_arn,
  :service_arn,
  :error_message,
  :account_targeting)
  SENSITIVE = []
  include Aws::Structure
end