Class: Aws::Resiliencehubv2::Types::TestRunSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::TestRunSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Contains summary information about a test run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_targeting ⇒ String
Indicates whether this test run targets a single account or multiple accounts.
-
#ended_at ⇒ Time
The timestamp when the test run ended.
-
#error_message ⇒ String
A human-readable reason for test run failure.
-
#service_arn ⇒ String
The ARN of the service the test run belongs to.
-
#started_at ⇒ Time
The timestamp when the test run started.
-
#status ⇒ String
The current status of the test run.
-
#test_run_id ⇒ String
The unique identifier of the test run.
-
#test_template_arn ⇒ String
The ARN of the test template the test run was based on.
Instance Attribute Details
#account_targeting ⇒ String
Indicates whether this test run targets a single account or multiple accounts.
5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The timestamp when the test run ended.
5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
A human-readable reason for test run failure. Only present when the status is FAILED or ERROR.
5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN of the service the test run belongs to.
5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp when the test run started.
5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the test run.
5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#test_run_id ⇒ String
The unique identifier of the test run.
5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#test_template_arn ⇒ String
The ARN of the test template the test run was based on.
5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5731 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |