Class: Aws::Resiliencehubv2::Types::TestRunSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::TestRunSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Contains summary information about a test run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_targeting ⇒ String
Indicates whether the test run targets resources in a single AWS account or across multiple accounts.
-
#ended_at ⇒ Time
The timestamp when the test run ended.
-
#error_message ⇒ String
A human-readable reason for test run failure.
-
#service_arn ⇒ String
The ARN of the service the test run belongs to.
-
#started_at ⇒ Time
The timestamp when the test run started.
-
#status ⇒ String
The current status of the test run.
-
#test_run_id ⇒ String
The unique identifier of the test run.
-
#test_template_arn ⇒ String
The ARN of the test template the test run was based on.
Instance Attribute Details
#account_targeting ⇒ String
Indicates whether the test run targets resources in a single AWS account or across multiple accounts.
6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The timestamp when the test run ended.
6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
A human-readable reason for test run failure. Only present when the status is FAILED or ERROR.
6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN of the service the test run belongs to.
6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp when the test run started.
6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the test run.
6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#test_run_id ⇒ String
The unique identifier of the test run.
6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |
#test_template_arn ⇒ String
The ARN of the test template the test run was based on.
6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 6045 class TestRunSummary < Struct.new( :test_run_id, :status, :started_at, :ended_at, :test_template_arn, :service_arn, :error_message, :account_targeting) SENSITIVE = [] include Aws::Structure end |