Class: Aws::Resiliencehubv2::Types::TestSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::TestSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
Contains summary information about a test.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The timestamp when the test was created.
-
#service_arn ⇒ String
The ARN of the service the test belongs to.
-
#successful_test_runs ⇒ Integer
The number of successful runs of the test.
-
#test_id ⇒ String
The unique identifier of the test.
-
#test_template_arn ⇒ String
The ARN of the test template the test was created from.
-
#total_test_runs ⇒ Integer
The total number of runs of the test.
Instance Attribute Details
#creation_time ⇒ Time
The timestamp when the test was created.
5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5829 class TestSummary < Struct.new( :test_id, :test_template_arn, :service_arn, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN of the service the test belongs to.
5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5829 class TestSummary < Struct.new( :test_id, :test_template_arn, :service_arn, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#successful_test_runs ⇒ Integer
The number of successful runs of the test.
5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5829 class TestSummary < Struct.new( :test_id, :test_template_arn, :service_arn, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#test_id ⇒ String
The unique identifier of the test.
5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5829 class TestSummary < Struct.new( :test_id, :test_template_arn, :service_arn, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#test_template_arn ⇒ String
The ARN of the test template the test was created from.
5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5829 class TestSummary < Struct.new( :test_id, :test_template_arn, :service_arn, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |
#total_test_runs ⇒ Integer
The total number of runs of the test.
5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5829 class TestSummary < Struct.new( :test_id, :test_template_arn, :service_arn, :total_test_runs, :successful_test_runs, :creation_time) SENSITIVE = [] include Aws::Structure end |