Class: Aws::Resiliencehubv2::Types::TestTemplate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Resiliencehubv2::Types::TestTemplate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehubv2/types.rb
Overview
A pre-configured, AWS recommended test that defines which resilience capability to validate, the fault actions it runs, and the parameters it accepts.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::TestAction>
The fault actions the test template runs.
-
#description ⇒ String
A description of the test template.
-
#name ⇒ String
The name of the test template.
-
#parameters ⇒ Array<Types::TestTemplateParameter>
The parameters the test template accepts.
-
#test_template_arn ⇒ String
The ARN of the test template.
Instance Attribute Details
#actions ⇒ Array<Types::TestAction>
The fault actions the test template runs.
5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5866 class TestTemplate < Struct.new( :test_template_arn, :name, :description, :parameters, :actions) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the test template.
5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5866 class TestTemplate < Struct.new( :test_template_arn, :name, :description, :parameters, :actions) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the test template.
5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5866 class TestTemplate < Struct.new( :test_template_arn, :name, :description, :parameters, :actions) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Array<Types::TestTemplateParameter>
The parameters the test template accepts.
5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5866 class TestTemplate < Struct.new( :test_template_arn, :name, :description, :parameters, :actions) SENSITIVE = [] include Aws::Structure end |
#test_template_arn ⇒ String
The ARN of the test template.
5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 5866 class TestTemplate < Struct.new( :test_template_arn, :name, :description, :parameters, :actions) SENSITIVE = [] include Aws::Structure end |