Class: Aws::Resiliencehubv2::Types::UserJourney

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehubv2/types.rb

Overview

Represents a user journey that defines a critical path through a system.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp when the user journey was created.

Returns:

  • (Time)


4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4943

class UserJourney < Struct.new(
  :user_journey_id,
  :name,
  :description,
  :policy_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Resource description.

Returns:

  • (String)


4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4943

class UserJourney < Struct.new(
  :user_journey_id,
  :name,
  :description,
  :policy_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Entity label (not part of ARN — spaces allowed).

Returns:

  • (String)


4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4943

class UserJourney < Struct.new(
  :user_journey_id,
  :name,
  :description,
  :policy_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#policy_arnString

ARN identifier.

Returns:

  • (String)


4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4943

class UserJourney < Struct.new(
  :user_journey_id,
  :name,
  :description,
  :policy_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp when the user journey was last updated.

Returns:

  • (Time)


4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4943

class UserJourney < Struct.new(
  :user_journey_id,
  :name,
  :description,
  :policy_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#user_journey_idString

The unique identifier of the user journey.

Returns:

  • (String)


4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
# File 'lib/aws-sdk-resiliencehubv2/types.rb', line 4943

class UserJourney < Struct.new(
  :user_journey_id,
  :name,
  :description,
  :policy_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end