Class: Aws::Resiliencehubv2::Waiters::ReportSucceeded
- Inherits:
-
Object
- Object
- Aws::Resiliencehubv2::Waiters::ReportSucceeded
- Defined in:
- lib/aws-sdk-resiliencehubv2/waiters.rb
Overview
Wait until report generation succeeds
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ReportSucceeded
constructor
A new instance of ReportSucceeded.
-
#wait(params = {}) ⇒ Types::ListReportsResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ReportSucceeded
Returns a new instance of ReportSucceeded.
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/aws-sdk-resiliencehubv2/waiters.rb', line 139 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :list_reports, acceptors: [ { "matcher" => "path", "argument" => "length(report_generation_results[]) == `0`", "state" => "retry", "expected" => true }, { "matcher" => "pathAll", "argument" => "report_generation_results[].status", "state" => "success", "expected" => "SUCCEEDED" }, { "matcher" => "pathAny", "argument" => "report_generation_results[].status", "state" => "failure", "expected" => "FAILED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
177 178 179 |
# File 'lib/aws-sdk-resiliencehubv2/waiters.rb', line 177 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::ListReportsResponse
Returns a response object which responds to the following methods:
-
#report_generation_results => Array<Types::ReportGenerationResult>
-
#next_token => String
172 173 174 |
# File 'lib/aws-sdk-resiliencehubv2/waiters.rb', line 172 def wait(params = {}) @waiter.wait(client: @client, params: params) end |